[Libreoffice-commits] core.git: vcl/headless vcl/inc vcl/osx vcl/quartz vcl/source vcl/unx vcl/win

Mark Page aptitude at btconnect.com
Fri Jun 10 07:26:24 UTC 2016


 vcl/headless/svptext.cxx                       |    2 
 vcl/inc/headless/svpgdi.hxx                    |    2 
 vcl/inc/image.h                                |    3 
 vcl/inc/opengl/program.hxx                     |    3 
 vcl/inc/osx/salinst.h                          |    3 
 vcl/inc/outdev.h                               |    3 
 vcl/inc/quartz/salgdi.h                        |    3 
 vcl/inc/salgdi.hxx                             |    3 
 vcl/inc/sallayout.hxx                          |    3 
 vcl/inc/textrender.hxx                         |    2 
 vcl/inc/unx/cairotextrender.hxx                |    2 
 vcl/inc/unx/fontcache.hxx                      |    3 
 vcl/inc/unx/genpspgraphics.h                   |    4 -
 vcl/inc/unx/gtk/gtkgdi.hxx                     |   47 +++++++--------
 vcl/inc/unx/salgdi.h                           |    2 
 vcl/inc/win/salbmp.h                           |    5 -
 vcl/inc/win/salgdi.h                           |    5 -
 vcl/osx/salinst.cxx                            |    4 -
 vcl/quartz/salgdi.cxx                          |   16 ++---
 vcl/quartz/salgdicommon.cxx                    |    3 
 vcl/source/edit/textdoc.cxx                    |   12 +--
 vcl/source/edit/textdoc.hxx                    |    3 
 vcl/source/filter/FilterConfigCache.cxx        |   20 +++---
 vcl/source/filter/FilterConfigCache.hxx        |    5 -
 vcl/source/filter/wmf/winmtf.cxx               |    6 -
 vcl/source/filter/wmf/winmtf.hxx               |    8 --
 vcl/source/font/fontcharmap.cxx                |   15 +---
 vcl/source/fontsubset/cff.cxx                  |   25 +++-----
 vcl/source/fontsubset/gsub.cxx                 |    8 --
 vcl/source/gdi/pdffontcache.hxx                |    2 
 vcl/source/gdi/pdfwriter_impl.cxx              |    4 -
 vcl/source/gdi/pdfwriter_impl.hxx              |    3 
 vcl/source/gdi/sallayout.cxx                   |   32 +++++-----
 vcl/source/image/ImplImageList.cxx             |    4 -
 vcl/source/outdev/font.cxx                     |    4 -
 vcl/source/window/debugevent.cxx               |    5 -
 vcl/source/window/splitwin.cxx                 |   31 ++++------
 vcl/unx/generic/fontmanager/fontcache.cxx      |   14 ++--
 vcl/unx/generic/gdi/cairotextrender.cxx        |    2 
 vcl/unx/generic/gdi/font.cxx                   |    2 
 vcl/unx/generic/glyphs/freetype_glyphcache.cxx |    8 --
 vcl/unx/generic/print/genpspgraphics.cxx       |    4 -
 vcl/unx/gtk/salnativewidgets-gtk.cxx           |   76 ++++++++++++-------------
 vcl/win/gdi/gdiimpl.cxx                        |    6 -
 vcl/win/gdi/salbmp.cxx                         |    2 
 vcl/win/gdi/salfont.cxx                        |    2 
 46 files changed, 197 insertions(+), 224 deletions(-)

New commits:
commit 99200d7cc2a952f92074934c647db076aae5e48b
Author: Mark Page <aptitude at btconnect.com>
Date:   Thu Jun 9 15:53:20 2016 +0100

    tdf#96099 Remove various smart pointer typedefs in vcl
    
    Change-Id: I4ac1bb25d3d63f150b42d9e1708efc344bbdb6a7
    Reviewed-on: https://gerrit.libreoffice.org/26113
    Tested-by: Jenkins <ci at libreoffice.org>
    Reviewed-by: Noel Grandin <noelgrandin at gmail.com>

diff --git a/vcl/headless/svptext.cxx b/vcl/headless/svptext.cxx
index e8fd525..ac7d3dc 100644
--- a/vcl/headless/svptext.cxx
+++ b/vcl/headless/svptext.cxx
@@ -95,7 +95,7 @@ void SvpSalGraphics::FreeEmbedFontData( const void* pData, long nLen )
 
 void SvpSalGraphics::GetGlyphWidths( const PhysicalFontFace* pFont,
                                    bool bVertical,
-                                   Int32Vector& rWidths,
+                                   std::vector< sal_Int32 >& rWidths,
                                    Ucs2UIntMap& rUnicodeEnc )
 {
     m_aTextRenderImpl.GetGlyphWidths(pFont, bVertical, rWidths, rUnicodeEnc);
diff --git a/vcl/inc/headless/svpgdi.hxx b/vcl/inc/headless/svpgdi.hxx
index 372be72..bb2e2f5 100644
--- a/vcl/inc/headless/svpgdi.hxx
+++ b/vcl/inc/headless/svpgdi.hxx
@@ -147,7 +147,7 @@ public:
     virtual void            FreeEmbedFontData( const void* pData, long nDataLen ) override;
     virtual void            GetGlyphWidths( const PhysicalFontFace*,
                                             bool bVertical,
-                                            Int32Vector& rWidths,
+                                            std::vector< sal_Int32 >& rWidths,
                                             Ucs2UIntMap& rUnicodeEnc ) override;
     virtual bool            GetGlyphBoundRect( sal_GlyphId nIndex, Rectangle& ) override;
     virtual bool            GetGlyphOutline( sal_GlyphId nIndex, basegfx::B2DPolyPolygon& ) override;
diff --git a/vcl/inc/image.h b/vcl/inc/image.h
index 9ab275a..f737a14 100644
--- a/vcl/inc/image.h
+++ b/vcl/inc/image.h
@@ -45,11 +45,10 @@ struct ImageAryData
 
 struct ImplImageList
 {
-    typedef std::vector<ImageAryData *> ImageAryDataVec;
     typedef std::unordered_map< OUString, ImageAryData *, OUStringHash >
         ImageAryDataNameHash;
 
-    ImageAryDataVec        maImages;
+    std::vector<ImageAryData *>        maImages;
     ImageAryDataNameHash   maNameHash;
     OUString               maPrefix;
     Size                   maImageSize;
diff --git a/vcl/inc/opengl/program.hxx b/vcl/inc/opengl/program.hxx
index b32aa05..82f5c2c 100644
--- a/vcl/inc/opengl/program.hxx
+++ b/vcl/inc/opengl/program.hxx
@@ -25,7 +25,6 @@
 #include <unordered_map>
 
 typedef std::unordered_map< OString, GLuint, OStringHash > UniformCache;
-typedef std::list< OpenGLTexture > TextureList;
 
 enum class TextureShaderType
 {
@@ -55,7 +54,7 @@ private:
     GLuint          mnExtrusionVectorsAttrib;
     GLuint          mnVertexColorsAttrib;
 
-    TextureList     maTextures;
+    std::list< OpenGLTexture >     maTextures;
     bool            mbBlending;
 
     float mfLastWidth;
diff --git a/vcl/inc/osx/salinst.h b/vcl/inc/osx/salinst.h
index 6144825..2047ec5 100644
--- a/vcl/inc/osx/salinst.h
+++ b/vcl/inc/osx/salinst.h
@@ -75,8 +75,7 @@ public:
     osl::Mutex                              maUserEventListMutex;
     oslCondition                            maWaitingYieldCond;
 
-    typedef std::list<const ApplicationEvent*> AppEventList;
-    static AppEventList aAppEventList;
+    static std::list<const ApplicationEvent*> aAppEventList;
 
 public:
     AquaSalInstance();
diff --git a/vcl/inc/outdev.h b/vcl/inc/outdev.h
index 1a06185..82750c2 100644
--- a/vcl/inc/outdev.h
+++ b/vcl/inc/outdev.h
@@ -96,8 +96,7 @@ class ImplDirectFontSubstitution
 :   public ImplFontSubstitution
 {
 private:
-    typedef std::list<ImplFontSubstEntry> FontSubstList;
-    FontSubstList maFontSubstList;
+    std::list<ImplFontSubstEntry> maFontSubstList;
 public:
     void    AddFontSubstitute( const OUString& rFontName, const OUString& rSubstName, AddFontSubstituteFlags nFlags );
     void    RemoveFontSubstitute( int nIndex );
diff --git a/vcl/inc/quartz/salgdi.h b/vcl/inc/quartz/salgdi.h
index 3f051a4..3cf501d 100644
--- a/vcl/inc/quartz/salgdi.h
+++ b/vcl/inc/quartz/salgdi.h
@@ -52,7 +52,6 @@ class CoreTextStyle;
 class XorEmulation;
 
 typedef sal_uInt32 sal_GlyphId;
-typedef std::vector<unsigned char> ByteVector;
 
 // CoreText-specific physically available font face
 class CoreTextFontFace : public PhysicalFontFace
@@ -395,7 +394,7 @@ public:
 
     virtual void            GetGlyphWidths( const PhysicalFontFace*,
                                             bool bVertical,
-                                            Int32Vector& rWidths,
+                                            std::vector< sal_Int32 >& rWidths,
                                             Ucs2UIntMap& rUnicodeEnc ) override;
 
     virtual bool            GetGlyphBoundRect( sal_GlyphId, Rectangle& ) override;
diff --git a/vcl/inc/salgdi.hxx b/vcl/inc/salgdi.hxx
index 5dd9b4c..51b5e3e 100644
--- a/vcl/inc/salgdi.hxx
+++ b/vcl/inc/salgdi.hxx
@@ -60,7 +60,6 @@ typedef sal_Unicode sal_Ucs; // TODO: use sal_UCS4 instead of sal_Unicode
 typedef std::map< sal_Ucs, sal_Int32 >    Ucs2SIntMap;
 typedef std::map< sal_Ucs, sal_uInt32 >   Ucs2UIntMap;
 typedef std::map< sal_Ucs, OString > Ucs2OStrMap;
-typedef std::vector< sal_Int32 > Int32Vector;
 
 // note: if you add any new methods to class SalGraphics using coordinates
 //       make sure they have a corresponding protected pure virtual method
@@ -210,7 +209,7 @@ public:
     virtual void                GetGlyphWidths(
                                     const PhysicalFontFace* pFont,
                                     bool bVertical,
-                                    Int32Vector& rWidths,
+                                    std::vector< sal_Int32 >& rWidths,
                                     Ucs2UIntMap& rUnicodeEnc ) = 0;
 
     virtual bool                GetGlyphBoundRect( sal_GlyphId, Rectangle& ) = 0;
diff --git a/vcl/inc/sallayout.hxx b/vcl/inc/sallayout.hxx
index daae365..6e0cc30 100644
--- a/vcl/inc/sallayout.hxx
+++ b/vcl/inc/sallayout.hxx
@@ -319,7 +319,6 @@ public:
 };
 
 typedef std::list<GlyphItem> GlyphList;
-typedef std::vector<GlyphItem> GlyphVector;
 
 class VCL_PLUGIN_PUBLIC GenericSalLayout : public SalLayout
 {
@@ -356,7 +355,7 @@ protected:
 
     bool            GetCharWidths( DeviceCoordinate* pCharWidths ) const;
 
-    GlyphVector     m_GlyphItems;
+    std::vector<GlyphItem>     m_GlyphItems;
 
 private:
     mutable Point   maBasePoint;
diff --git a/vcl/inc/textrender.hxx b/vcl/inc/textrender.hxx
index e08274e..29559aa 100644
--- a/vcl/inc/textrender.hxx
+++ b/vcl/inc/textrender.hxx
@@ -65,7 +65,7 @@ public:
     virtual void                    GetGlyphWidths(
                                         const PhysicalFontFace*,
                                         bool bVertical,
-                                        Int32Vector& rWidths,
+                                        std::vector< sal_Int32 >& rWidths,
                                         Ucs2UIntMap& rUnicodeEnc ) = 0;
 
     virtual bool                    GetGlyphBoundRect( sal_GlyphId nIndex, Rectangle& ) = 0;
diff --git a/vcl/inc/unx/cairotextrender.hxx b/vcl/inc/unx/cairotextrender.hxx
index 612daae..1e2eb9c 100644
--- a/vcl/inc/unx/cairotextrender.hxx
+++ b/vcl/inc/unx/cairotextrender.hxx
@@ -112,7 +112,7 @@ public:
     virtual void                GetGlyphWidths(
                                     const PhysicalFontFace*,
                                     bool bVertical,
-                                    Int32Vector& rWidths,
+                                    std::vector< sal_Int32 >& rWidths,
                                     Ucs2UIntMap& rUnicodeEnc ) override;
 
     virtual bool                GetGlyphBoundRect( sal_GlyphId nIndex, Rectangle& ) override;
diff --git a/vcl/inc/unx/fontcache.hxx b/vcl/inc/unx/fontcache.hxx
index 9c40040..98a7c8b 100644
--- a/vcl/inc/unx/fontcache.hxx
+++ b/vcl/inc/unx/fontcache.hxx
@@ -36,10 +36,9 @@ class VCL_PLUGIN_PUBLIC FontCache
     struct FontFile;
     friend struct FontFile;
 
-    typedef std::list< PrintFontManager::PrintFont* > FontCacheEntry;
     struct FontFile
     {
-        FontCacheEntry      m_aEntry;
+        std::list< PrintFontManager::PrintFont* >      m_aEntry;
     };
 
     typedef std::unordered_map< OString, FontFile, OStringHash > FontDirMap;
diff --git a/vcl/inc/unx/genpspgraphics.h b/vcl/inc/unx/genpspgraphics.h
index 01b3c6a..339ec16 100644
--- a/vcl/inc/unx/genpspgraphics.h
+++ b/vcl/inc/unx/genpspgraphics.h
@@ -67,7 +67,7 @@ public:
                                                        std::set<sal_Unicode> const** ppPriority);
     static void             DoGetGlyphWidths( psp::fontID aFont,
                                               bool bVertical,
-                                              Int32Vector& rWidths,
+                                              std::vector< sal_Int32 >& rWidths,
                                               Ucs2UIntMap& rUnicodeEnc );
 
     static FontAttributes Info2FontAttributes( const psp::FastPrintFontInfo& );
@@ -126,7 +126,7 @@ public:
     virtual void            FreeEmbedFontData( const void* pData, long nDataLen ) override;
     virtual void            GetGlyphWidths( const PhysicalFontFace*,
                                             bool bVertical,
-                                            Int32Vector& rWidths,
+                                            std::vector< sal_Int32 >& rWidths,
                                             Ucs2UIntMap& rUnicodeEnc ) override;
     virtual bool            GetGlyphBoundRect( sal_GlyphId, Rectangle& ) override;
     virtual bool            GetGlyphOutline( sal_GlyphId, basegfx::B2DPolyPolygon& ) override;
diff --git a/vcl/inc/unx/gtk/gtkgdi.hxx b/vcl/inc/unx/gtk/gtkgdi.hxx
index 3aac4d1..f0880c6 100644
--- a/vcl/inc/unx/gtk/gtkgdi.hxx
+++ b/vcl/inc/unx/gtk/gtkgdi.hxx
@@ -243,7 +243,6 @@ public:
                                       SalGraphics* pSrcGraphics ) override;
 
 protected:
-    typedef std::list< Rectangle > clipList;
 
     GdkX11Pixmap* NWGetPixmapFromScreen( Rectangle srcRect, int nBgColor = 0 );
     bool NWRenderPixmapToScreen( GdkX11Pixmap* pPixmap, GdkX11Pixmap* pMask, Rectangle dstRect );
@@ -252,7 +251,7 @@ protected:
                            ControlType nType,
                            ControlPart nPart,
                            const Rectangle& aCtrlRect,
-                           const clipList& aClip,
+                           const std::list< Rectangle >& aClip,
                            ControlState nState,
                            const ImplControlValue& aValue,
                            const OUString& rCaption,
@@ -260,114 +259,114 @@ protected:
 
     bool NWPaintGTKArrow( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                            const Rectangle& rControlRectangle,
-                           const clipList& rClipList,
+                           const std::list< Rectangle >& rClipList,
                            ControlState nState, const ImplControlValue& aValue,
                            const OUString& rCaption );
     bool NWPaintGTKListHeader( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                            const Rectangle& rControlRectangle,
-                           const clipList& rClipList,
+                           const std::list< Rectangle >& rClipList,
                            ControlState nState, const ImplControlValue& aValue,
                            const OUString& rCaption );
     bool NWPaintGTKFixedLine( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                            const Rectangle& rControlRectangle,
-                           const clipList& rClipList,
+                           const std::list< Rectangle >& rClipList,
                            ControlState nState, const ImplControlValue& aValue,
                            const OUString& rCaption );
     bool NWPaintGTKFrame( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                            const Rectangle& rControlRectangle,
-                           const clipList& rClipList,
+                           const std::list< Rectangle >& rClipList,
                            ControlState nState, const ImplControlValue& aValue,
                            const OUString& rCaption );
     bool NWPaintGTKWindowBackground( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                            const Rectangle& rControlRectangle,
-                           const clipList& rClipList,
+                           const std::list< Rectangle >& rClipList,
                            ControlState nState, const ImplControlValue& aValue,
                            const OUString& rCaption );
     bool NWPaintGTKButtonReal( GtkWidget* button, GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                            const Rectangle& rControlRectangle,
-                           const clipList& rClipList,
+                           const std::list< Rectangle >& rClipList,
                            ControlState nState, const ImplControlValue& aValue,
                            const OUString& rCaption );
     bool NWPaintGTKButton( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                            const Rectangle& rControlRectangle,
-                           const clipList& rClipList,
+                           const std::list< Rectangle >& rClipList,
                            ControlState nState, const ImplControlValue& aValue,
                            const OUString& rCaption );
     bool NWPaintGTKRadio( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                           const Rectangle& rControlRectangle,
-                          const clipList& rClipList,
+                          const std::list< Rectangle >& rClipList,
                           ControlState nState, const ImplControlValue& aValue,
                           const OUString& rCaption );
     bool NWPaintGTKCheck( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                           const Rectangle& rControlRectangle,
-                          const clipList& rClipList,
+                          const std::list< Rectangle >& rClipList,
                           ControlState nState, const ImplControlValue& aValue,
                           const OUString& rCaption );
     bool NWPaintGTKScrollbar( ControlType nType, ControlPart nPart,
                               const Rectangle& rControlRectangle,
-                              const clipList& rClipList,
+                              const std::list< Rectangle >& rClipList,
                               ControlState nState, const ImplControlValue& aValue,
                               const OUString& rCaption );
     bool NWPaintGTKEditBox( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                             const Rectangle& rControlRectangle,
-                            const clipList& rClipList,
+                            const std::list< Rectangle >& rClipList,
                             ControlState nState, const ImplControlValue& aValue,
                             const OUString& rCaption );
     bool NWPaintGTKSpinBox(ControlType nType, ControlPart nPart,
                            const Rectangle& rControlRectangle,
-                           const clipList& rClipList,
+                           const std::list< Rectangle >& rClipList,
                            ControlState nState, const ImplControlValue& aValue,
                            const OUString& rCaption,
                            ControlCacheKey& rControlCacheKey);
     bool NWPaintGTKComboBox( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                              const Rectangle& rControlRectangle,
-                             const clipList& rClipList,
+                             const std::list< Rectangle >& rClipList,
                              ControlState nState, const ImplControlValue& aValue,
                              const OUString& rCaption );
     bool NWPaintGTKTabItem( ControlType nType, ControlPart nPart,
                             const Rectangle& rControlRectangle,
-                            const clipList& rClipList,
+                            const std::list< Rectangle >& rClipList,
                             ControlState nState, const ImplControlValue& aValue,
                             const OUString& rCaption );
     bool NWPaintGTKListBox( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                             const Rectangle& rControlRectangle,
-                            const clipList& rClipList,
+                            const std::list< Rectangle >& rClipList,
                             ControlState nState, const ImplControlValue& aValue,
                             const OUString& rCaption );
 
     bool NWPaintGTKToolbar( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                             const Rectangle& rControlRectangle,
-                            const clipList& rClipList,
+                            const std::list< Rectangle >& rClipList,
                             ControlState nState, const ImplControlValue& aValue,
                             const OUString& rCaption );
     bool NWPaintGTKMenubar( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                             const Rectangle& rControlRectangle,
-                            const clipList& rClipList,
+                            const std::list< Rectangle >& rClipList,
                             ControlState nState, const ImplControlValue& aValue,
                             const OUString& rCaption );
     bool NWPaintGTKPopupMenu( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                               const Rectangle& rControlRectangle,
-                              const clipList& rClipList,
+                              const std::list< Rectangle >& rClipList,
                               ControlState nState, const ImplControlValue& aValue,
                               const OUString& rCaption );
     bool NWPaintGTKTooltip( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                             const Rectangle& rControlRectangle,
-                            const clipList& rClipList,
+                            const std::list< Rectangle >& rClipList,
                             ControlState nState, const ImplControlValue& aValue,
                             const OUString& rCaption );
     bool NWPaintGTKProgress( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                             const Rectangle& rControlRectangle,
-                            const clipList& rClipList,
+                            const std::list< Rectangle >& rClipList,
                             ControlState nState, const ImplControlValue& aValue,
                             const OUString& rCaption );
     bool NWPaintGTKSlider( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                            const Rectangle& rControlRectangle,
-                           const clipList& rClipList,
+                           const std::list< Rectangle >& rClipList,
                            ControlState nState, const ImplControlValue& aValue,
                            const OUString& rCaption );
     bool NWPaintGTKListNode( GdkDrawable* gdkDrawable, ControlType nType, ControlPart nPart,
                             const Rectangle& rControlRectangle,
-                            const clipList& rClipList,
+                            const std::list< Rectangle >& rClipList,
                             ControlState nState, const ImplControlValue& aValue,
                             const OUString& rCaption );
 };
diff --git a/vcl/inc/unx/salgdi.h b/vcl/inc/unx/salgdi.h
index cd59a0fc..15f6a49 100644
--- a/vcl/inc/unx/salgdi.h
+++ b/vcl/inc/unx/salgdi.h
@@ -148,7 +148,7 @@ public:
     virtual void                    GetGlyphWidths(
                                         const PhysicalFontFace*,
                                         bool bVertical,
-                                        Int32Vector& rWidths,
+                                        std::vector< sal_Int32 >& rWidths,
                                         Ucs2UIntMap& rUnicodeEnc ) override;
 
     virtual bool                    GetGlyphBoundRect( sal_GlyphId nIndex, Rectangle& ) override;
diff --git a/vcl/inc/win/salbmp.h b/vcl/inc/win/salbmp.h
index 0a698e5..5b24aca 100644
--- a/vcl/inc/win/salbmp.h
+++ b/vcl/inc/win/salbmp.h
@@ -31,7 +31,6 @@ class   BitmapColor;
 class   BitmapPalette;
 class   SalGraphics;
 namespace Gdiplus { class Bitmap; }
-typedef std::shared_ptr< Gdiplus::Bitmap > GdiPlusBmpPtr;
 
 class WinSalBitmap : public SalBitmap
 {
@@ -50,7 +49,7 @@ private:
     // evtl. buffered GdiPlusBmp. This is needed since the GdiPlusBmp is a single
     // instance and remembered only on the content-WinSalBitmap, not on the
     // alpha-WinSalBitmap.
-    GdiPlusBmpPtr       maGdiPlusBitmap;
+    std::shared_ptr< Gdiplus::Bitmap >       maGdiPlusBitmap;
     const WinSalBitmap* mpAssociatedAlpha;
 
     sal_uInt16          mnBitCount;
@@ -63,7 +62,7 @@ public:
     HGLOBAL             ImplGethDIB() const { return mhDIB; }
     HBITMAP             ImplGethDDB() const { return mhDDB; }
 
-    GdiPlusBmpPtr ImplGetGdiPlusBitmap(const WinSalBitmap* pAlphaSource = 0) const;
+    std::shared_ptr< Gdiplus::Bitmap > ImplGetGdiPlusBitmap(const WinSalBitmap* pAlphaSource = 0) const;
 
     static HGLOBAL      ImplCreateDIB( const Size& rSize, sal_uInt16 nBitCount, const BitmapPalette& rPal );
     static HANDLE       ImplCopyDIBOrDDB( HANDLE hHdl, bool bDIB );
diff --git a/vcl/inc/win/salgdi.h b/vcl/inc/win/salgdi.h
index 4ae6278..d87cbbd 100644
--- a/vcl/inc/win/salgdi.h
+++ b/vcl/inc/win/salgdi.h
@@ -136,8 +136,7 @@ private:
 
     void                    ReadGsubTable( HDC ) const;
 
-    typedef std::unordered_set<sal_UCS4> UcsHashSet;
-    mutable UcsHashSet      maGsubTable;
+    mutable std::unordered_set<sal_UCS4>      maGsubTable;
     mutable bool            mbGsubRead;
 public:
     bool                    HasGSUBstitutions( HDC ) const;
@@ -442,7 +441,7 @@ public:
     virtual void            FreeEmbedFontData( const void* pData, long nDataLen ) override;
     virtual void            GetGlyphWidths( const PhysicalFontFace*,
                                             bool bVertical,
-                                            Int32Vector& rWidths,
+                                            std::vector< sal_Int32 >& rWidths,
                                             Ucs2UIntMap& rUnicodeEnc ) override;
             int             GetMinKashidaWidth();
 
diff --git a/vcl/quartz/salgdi.cxx b/vcl/quartz/salgdi.cxx
index 6c62b81..67d1d82 100644
--- a/vcl/quartz/salgdi.cxx
+++ b/vcl/quartz/salgdi.cxx
@@ -108,7 +108,7 @@ const FontCharMapPtr CoreTextFontFace::GetFontCharMap() const
         return mxCharMap;
 
     // get the CMAP raw data
-    ByteVector aBuffer( nBufSize );
+    std::vector<unsigned char> aBuffer( nBufSize );
     const int nRawLength = GetFontTable( "cmap", &aBuffer[0] );
     DBG_ASSERT( (nRawLength > 0), "CoreTextFontFace::GetFontCharMap : GetFontTable2 failed!\n");
     if( nRawLength <= 0 )
@@ -144,7 +144,7 @@ bool CoreTextFontFace::GetFontCapabilities(vcl::FontCapabilities &rFontCapabilit
     if( nBufSize > 0 )
     {
         // allocate a buffer for the GSUB raw data
-        ByteVector aBuffer( nBufSize );
+        std::vector<unsigned char> aBuffer( nBufSize );
         // get the GSUB raw data
         const int nRawLength = GetFontTable( "GSUB", &aBuffer[0] );
         if( nRawLength > 0 )
@@ -157,7 +157,7 @@ bool CoreTextFontFace::GetFontCapabilities(vcl::FontCapabilities &rFontCapabilit
     if( nBufSize > 0 )
     {
         // allocate a buffer for the OS/2 raw data
-        ByteVector aBuffer( nBufSize );
+        std::vector<unsigned char> aBuffer( nBufSize );
         // get the OS/2 raw data
         const int nRawLength = GetFontTable( "OS/2", &aBuffer[0] );
         if( nRawLength > 0 )
@@ -188,7 +188,7 @@ void CoreTextFontFace::ReadOs2Table() const
         return;
 
     // get the OS/2 raw data
-    ByteVector aBuffer( nBufSize );
+    std::vector<unsigned char> aBuffer( nBufSize );
     const int nRawLength = GetFontTable( "cmap", &aBuffer[0] );
     DBG_ASSERT( (nRawLength > 0), "CoreTextFontFace::ReadOs2Table : GetFontTable2 failed!\n");
     if( nRawLength <= 0 )
@@ -214,7 +214,7 @@ void CoreTextFontFace::ReadMacCmapEncoding() const
         return;
 
     // get the CMAP raw data
-    ByteVector aBuffer( nBufSize );
+    std::vector<unsigned char> aBuffer( nBufSize );
     const int nRawLength = GetFontTable( "cmap", &aBuffer[0] );
     if( nRawLength < 24 )
         return;
@@ -503,7 +503,7 @@ static void FakeDirEntry( const char aTag[5], ByteCount nOfs, ByteCount nLen,
 // fake a TTF or CFF font as directly accessing font file is not possible
 // when only the fontid is known. This approach also handles *.font fonts.
 bool AquaSalGraphics::GetRawFontData( const PhysicalFontFace* pFontData,
-                                      ByteVector& rBuffer, bool* pJustCFF )
+                                      std::vector<unsigned char>& rBuffer, bool* pJustCFF )
 {
     const CoreTextFontFace* pMacFont = static_cast<const CoreTextFontFace*>(pFontData);
 
@@ -689,7 +689,7 @@ bool AquaSalGraphics::GetRawFontData( const PhysicalFontFace* pFontData,
 }
 
 void AquaSalGraphics::GetGlyphWidths( const PhysicalFontFace* pFontData, bool bVertical,
-    Int32Vector& rGlyphWidths, Ucs2UIntMap& rUnicodeEnc )
+    std::vector< sal_Int32 >& rGlyphWidths, Ucs2UIntMap& rUnicodeEnc )
 {
     rGlyphWidths.clear();
     rUnicodeEnc.clear();
@@ -704,7 +704,7 @@ void AquaSalGraphics::GetGlyphWidths( const PhysicalFontFace* pFontData, bool bV
         return;
     }
 
-    ByteVector aBuffer;
+    std::vector<unsigned char> aBuffer;
     if( !GetRawFontData( pFontData, aBuffer, nullptr ) )
         return;
 
diff --git a/vcl/quartz/salgdicommon.cxx b/vcl/quartz/salgdicommon.cxx
index bdcf538..9b966c6 100644
--- a/vcl/quartz/salgdicommon.cxx
+++ b/vcl/quartz/salgdicommon.cxx
@@ -73,7 +73,6 @@ extern int DBG_DRAW_ROUNDS, DBG_DRAW_COUNTER, DBG_DRAW_DEPTH;
 
 using namespace vcl;
 
-typedef std::vector<unsigned char> ByteVector;
 
 static const basegfx::B2DPoint aHalfPointOfs ( 0.5, 0.5 );
 
@@ -195,7 +194,7 @@ bool AquaSalGraphics::CreateFontSubset( const OUString& rToFile,
     }
 
     // get the raw-bytes from the font to be subset
-    ByteVector aBuffer;
+    std::vector<unsigned char> aBuffer;
     bool bCffOnly = false;
     if( !GetRawFontData( pFontData, aBuffer, &bCffOnly ) )
     {
diff --git a/vcl/source/edit/textdoc.cxx b/vcl/source/edit/textdoc.cxx
index 866c267..eceaeb8 100644
--- a/vcl/source/edit/textdoc.cxx
+++ b/vcl/source/edit/textdoc.cxx
@@ -68,7 +68,7 @@ void TextCharAttribList::InsertAttrib( TextCharAttrib* pAttrib )
 
     const sal_Int32 nStart = pAttrib->GetStart(); // maybe better for Comp.Opt.
     bool bInserted = false;
-    for (TextCharAttribs::iterator it = maAttribs.begin(); it != maAttribs.end(); ++it)
+    for (std::vector<std::unique_ptr<TextCharAttrib> >::iterator it = maAttribs.begin(); it != maAttribs.end(); ++it)
     {
         if ( (*it)->GetStart() > nStart )
         {
@@ -88,7 +88,7 @@ void TextCharAttribList::ResortAttribs()
 
 TextCharAttrib* TextCharAttribList::FindAttrib( sal_uInt16 nWhich, sal_Int32 nPos )
 {
-    for (TextCharAttribs::reverse_iterator it = maAttribs.rbegin(); it != maAttribs.rend(); ++it)
+    for (std::vector<std::unique_ptr<TextCharAttrib> >::reverse_iterator it = maAttribs.rbegin(); it != maAttribs.rend(); ++it)
     {
         if ( (*it)->GetEnd() < nPos )
             return nullptr;
@@ -102,7 +102,7 @@ TextCharAttrib* TextCharAttribList::FindAttrib( sal_uInt16 nWhich, sal_Int32 nPo
 const TextCharAttrib* TextCharAttribList::FindNextAttrib( sal_uInt16 nWhich, sal_Int32 nFromPos, sal_Int32 nMaxPos ) const
 {
     DBG_ASSERT( nWhich, "FindNextAttrib: Which?" );
-    for (TextCharAttribs::const_iterator it = maAttribs.begin(); it != maAttribs.end(); ++it)
+    for (std::vector<std::unique_ptr<TextCharAttrib> >::const_iterator it = maAttribs.begin(); it != maAttribs.end(); ++it)
     {
         if ( ( (*it)->GetStart() >= nFromPos ) &&
              ( (*it)->GetEnd() <= nMaxPos ) &&
@@ -114,7 +114,7 @@ const TextCharAttrib* TextCharAttribList::FindNextAttrib( sal_uInt16 nWhich, sal
 
 bool TextCharAttribList::HasAttrib( sal_uInt16 nWhich ) const
 {
-    for (TextCharAttribs::const_reverse_iterator it = maAttribs.rbegin(); it != maAttribs.rend(); ++it)
+    for (std::vector<std::unique_ptr<TextCharAttrib> >::const_reverse_iterator it = maAttribs.rbegin(); it != maAttribs.rend(); ++it)
     {
         if ( (*it)->Which() == nWhich )
             return true;
@@ -124,7 +124,7 @@ bool TextCharAttribList::HasAttrib( sal_uInt16 nWhich ) const
 
 bool TextCharAttribList::HasBoundingAttrib( sal_Int32 nBound )
 {
-    for (TextCharAttribs::reverse_iterator it = maAttribs.rbegin(); it != maAttribs.rend(); ++it)
+    for (std::vector<std::unique_ptr<TextCharAttrib> >::reverse_iterator it = maAttribs.rbegin(); it != maAttribs.rend(); ++it)
     {
         if ( (*it)->GetEnd() < nBound )
             return false;
@@ -140,7 +140,7 @@ TextCharAttrib* TextCharAttribList::FindEmptyAttrib( sal_uInt16 nWhich, sal_Int3
     if ( !mbHasEmptyAttribs )
         return nullptr;
 
-    for (TextCharAttribs::iterator it = maAttribs.begin(); it != maAttribs.end(); ++it)
+    for (std::vector<std::unique_ptr<TextCharAttrib> >::iterator it = maAttribs.begin(); it != maAttribs.end(); ++it)
     {
         if ( (*it)->GetStart() > nPos )
             return nullptr;
diff --git a/vcl/source/edit/textdoc.hxx b/vcl/source/edit/textdoc.hxx
index 91ff2ac..9f8b5fc 100644
--- a/vcl/source/edit/textdoc.hxx
+++ b/vcl/source/edit/textdoc.hxx
@@ -32,8 +32,7 @@ private:
     TextCharAttribList(const TextCharAttribList&) = delete;
     TextCharAttribList& operator=(const TextCharAttribList&) = delete;
 
-    typedef std::vector<std::unique_ptr<TextCharAttrib> > TextCharAttribs;
-    TextCharAttribs maAttribs;
+    std::vector<std::unique_ptr<TextCharAttrib> > maAttribs;
     bool            mbHasEmptyAttribs;
 
 public:
diff --git a/vcl/source/filter/FilterConfigCache.cxx b/vcl/source/filter/FilterConfigCache.cxx
index 3d5ad91..dce03d7 100644
--- a/vcl/source/filter/FilterConfigCache.cxx
+++ b/vcl/source/filter/FilterConfigCache.cxx
@@ -316,7 +316,7 @@ OUString FilterConfigCache::GetImportFilterName( sal_uInt16 nFormat )
 
 sal_uInt16 FilterConfigCache::GetImportFormatNumber( const OUString& rFormatName )
 {
-    CacheVector::const_iterator aIter, aEnd;
+    std::vector< FilterConfigCacheEntry >::const_iterator aIter, aEnd;
     for (aIter = aImport.begin(), aEnd = aImport.end(); aIter != aEnd; ++aIter)
     {
         if ( aIter->sUIName.equalsIgnoreAsciiCase( rFormatName ) )
@@ -328,7 +328,7 @@ sal_uInt16 FilterConfigCache::GetImportFormatNumber( const OUString& rFormatName
 /// get the index of the filter that matches this extension
 sal_uInt16 FilterConfigCache::GetImportFormatNumberForExtension( const OUString& rExt )
 {
-    CacheVector::const_iterator aIter, aEnd;
+    std::vector< FilterConfigCacheEntry >::const_iterator aIter, aEnd;
     for (aIter = aImport.begin(), aEnd = aImport.end(); aIter != aEnd; ++aIter)
     {
         for ( sal_Int32 i = 0; i < aIter->lExtensionList.getLength(); i++ )
@@ -342,8 +342,8 @@ sal_uInt16 FilterConfigCache::GetImportFormatNumberForExtension( const OUString&
 
 sal_uInt16 FilterConfigCache::GetImportFormatNumberForShortName( const OUString& rShortName )
 {
-    CacheVector::const_iterator aEnd;
-    CacheVector::iterator aIter;
+    std::vector< FilterConfigCacheEntry >::const_iterator aEnd;
+    std::vector< FilterConfigCacheEntry >::iterator aIter;
     for (aIter = aImport.begin(), aEnd = aImport.end(); aIter != aEnd; ++aIter)
     {
         if ( aIter->GetShortName().equalsIgnoreAsciiCase( rShortName ) )
@@ -354,7 +354,7 @@ sal_uInt16 FilterConfigCache::GetImportFormatNumberForShortName( const OUString&
 
 sal_uInt16 FilterConfigCache::GetImportFormatNumberForTypeName( const OUString& rType )
 {
-    CacheVector::const_iterator aIter, aEnd;
+    std::vector< FilterConfigCacheEntry >::const_iterator aIter, aEnd;
     for (aIter = aImport.begin(), aEnd = aImport.end(); aIter != aEnd; ++aIter)
     {
         if ( aIter->sType.equalsIgnoreAsciiCase( rType ) )
@@ -442,7 +442,7 @@ OUString FilterConfigCache::GetExportFilterName( sal_uInt16 nFormat )
 
 sal_uInt16 FilterConfigCache::GetExportFormatNumber(const OUString& rFormatName)
 {
-    CacheVector::const_iterator aIter, aEnd;
+    std::vector< FilterConfigCacheEntry >::const_iterator aIter, aEnd;
     for (aIter = aExport.begin(), aEnd = aExport.end(); aIter != aEnd; ++aIter)
     {
         if ( aIter->sUIName.equalsIgnoreAsciiCase( rFormatName ) )
@@ -453,7 +453,7 @@ sal_uInt16 FilterConfigCache::GetExportFormatNumber(const OUString& rFormatName)
 
 sal_uInt16 FilterConfigCache::GetExportFormatNumberForMediaType( const OUString& rMediaType )
 {
-    CacheVector::const_iterator aIter, aEnd;
+    std::vector< FilterConfigCacheEntry >::const_iterator aIter, aEnd;
     for (aIter = aExport.begin(), aEnd = aExport.end(); aIter != aEnd; ++aIter)
     {
         if ( aIter->sMediaType.equalsIgnoreAsciiCase( rMediaType ) )
@@ -464,8 +464,8 @@ sal_uInt16 FilterConfigCache::GetExportFormatNumberForMediaType( const OUString&
 
 sal_uInt16 FilterConfigCache::GetExportFormatNumberForShortName( const OUString& rShortName )
 {
-    CacheVector::const_iterator aEnd;
-    CacheVector::iterator aIter;
+    std::vector< FilterConfigCacheEntry >::const_iterator aEnd;
+    std::vector< FilterConfigCacheEntry >::iterator aIter;
     for (aIter = aExport.begin(), aEnd = aExport.end(); aIter != aEnd; ++aIter)
     {
         if ( aIter->GetShortName().equalsIgnoreAsciiCase( rShortName ) )
@@ -476,7 +476,7 @@ sal_uInt16 FilterConfigCache::GetExportFormatNumberForShortName( const OUString&
 
 sal_uInt16 FilterConfigCache::GetExportFormatNumberForTypeName( const OUString& rType )
 {
-    CacheVector::const_iterator aIter, aEnd;
+    std::vector< FilterConfigCacheEntry >::const_iterator aIter, aEnd;
     for (aIter = aExport.begin(), aEnd = aExport.end(); aIter != aEnd; ++aIter)
     {
         if ( aIter->sType.equalsIgnoreAsciiCase( rType ) )
diff --git a/vcl/source/filter/FilterConfigCache.hxx b/vcl/source/filter/FilterConfigCache.hxx
index d49752d..eb32218 100644
--- a/vcl/source/filter/FilterConfigCache.hxx
+++ b/vcl/source/filter/FilterConfigCache.hxx
@@ -55,10 +55,9 @@ class FilterConfigCache
         static const char* ExternalPixelFilterNameList[];
     };
 
-    typedef std::vector< FilterConfigCacheEntry > CacheVector;
 
-    CacheVector         aImport;
-    CacheVector         aExport;
+    std::vector< FilterConfigCacheEntry >         aImport;
+    std::vector< FilterConfigCacheEntry >         aExport;
     bool            bUseConfig;
 
     static bool   bInitialized;
diff --git a/vcl/source/filter/wmf/winmtf.cxx b/vcl/source/filter/wmf/winmtf.cxx
index 2057643..804b704 100644
--- a/vcl/source/filter/wmf/winmtf.cxx
+++ b/vcl/source/filter/wmf/winmtf.cxx
@@ -1592,7 +1592,7 @@ void WinMtfOutput::ImplDrawBitmap( const Point& rPos, const Size& rSize, const B
         mpGDIMetaFile->AddAction( new MetaBmpScaleAction( rPos, rSize, aBmpEx.GetBitmap() ) );
 }
 
-void WinMtfOutput::ResolveBitmapActions( BSaveStructList_impl& rSaveList )
+void WinMtfOutput::ResolveBitmapActions( std::vector<std::unique_ptr<BSaveStruct>>& rSaveList )
 {
     UpdateClipRegion();
 
@@ -2056,7 +2056,7 @@ void WinMtfOutput::ModifyWorldTransform( const XForm& rXForm, sal_uInt32 nMode )
 void WinMtfOutput::Push()                       // !! to be able to access the original ClipRegion it
 {                                               // is not allowed to use the MetaPushAction()
     UpdateClipRegion();                         // (the original clip region is on top of the stack) (SJ)
-    SaveStructPtr pSave( new SaveStruct );
+    std::shared_ptr<SaveStruct> pSave( new SaveStruct );
 
     pSave->aLineStyle = maLineStyle;
     pSave->aFillStyle = maFillStyle;
@@ -2096,7 +2096,7 @@ void WinMtfOutput::Pop()
     if( !vSaveStack.empty() )
     {
         // Backup the current data on the stack
-        SaveStructPtr pSave( vSaveStack.back() );
+        std::shared_ptr<SaveStruct> pSave( vSaveStack.back() );
 
         maLineStyle = pSave->aLineStyle;
         maFillStyle = pSave->aFillStyle;
diff --git a/vcl/source/filter/wmf/winmtf.hxx b/vcl/source/filter/wmf/winmtf.hxx
index a1ba920..542c72a 100644
--- a/vcl/source/filter/wmf/winmtf.hxx
+++ b/vcl/source/filter/wmf/winmtf.hxx
@@ -440,7 +440,6 @@ struct SaveStruct
     bool                bFillStyleSelected;
 };
 
-typedef std::shared_ptr<SaveStruct> SaveStructPtr;
 
 struct BSaveStruct
 {
@@ -461,7 +460,6 @@ struct BSaveStruct
     {}
 };
 
-typedef std::vector<std::unique_ptr<BSaveStruct>> BSaveStructList_impl;
 
 class WinMtfOutput
 {
@@ -499,7 +497,7 @@ class WinMtfOutput
     bool            mbClipNeedsUpdate;
     bool            mbComplexClip;
 
-    std::vector< SaveStructPtr > vSaveStack;
+    std::vector< std::shared_ptr<SaveStruct> > vSaveStack;
 
     sal_uInt32          mnGfxMode;
     sal_uInt32          mnMapMode;
@@ -632,7 +630,7 @@ public:
                                   bool bRecordPath = false,
                                   sal_Int32 nGraphicsMode = GM_COMPATIBLE);
 
-    void                ResolveBitmapActions( BSaveStructList_impl& rSaveList );
+    void                ResolveBitmapActions( std::vector<std::unique_ptr<BSaveStruct>>& rSaveList );
 
     void                IntersectClipRect( const Rectangle& rRect );
     void                ExcludeClipRect( const Rectangle& rRect );
@@ -661,7 +659,7 @@ protected:
     SvStream*               pWMF;               // the WMF/EMF file to be read
 
     sal_uInt32              nStartPos, nEndPos;
-    BSaveStructList_impl    aBmpSaveList;
+    std::vector<std::unique_ptr<BSaveStruct>>    aBmpSaveList;
 
     FilterConfigItem*   pFilterConfigItem;
 
diff --git a/vcl/source/font/fontcharmap.cxx b/vcl/source/font/fontcharmap.cxx
index 6c458b5..821427d 100644
--- a/vcl/source/font/fontcharmap.cxx
+++ b/vcl/source/font/fontcharmap.cxx
@@ -169,8 +169,7 @@ bool ParseCMAP( const unsigned char* pCmap, int nLength, CmapResult& rResult )
     sal_UCS4* pCodePairs = nullptr;
     int* pStartGlyphs = nullptr;
 
-    typedef std::vector<sal_uInt16> U16Vector;
-    U16Vector aGlyphIdArray;
+    std::vector<sal_uInt16> aGlyphIdArray;
     aGlyphIdArray.reserve( 0x1000 );
     aGlyphIdArray.push_back( 0 );
 
@@ -291,8 +290,7 @@ bool ParseCMAP( const unsigned char* pCmap, int nLength, CmapResult& rResult )
     if( aConverter && aCvtContext )
     {
         // determine the set of supported unicodes from encoded ranges
-        typedef std::set<sal_UCS4> Ucs4Set;
-        Ucs4Set aSupportedUnicodes;
+        std::set<sal_UCS4> aSupportedUnicodes;
 
         static const int NINSIZE = 64;
         static const int NOUTSIZE = 64;
@@ -332,10 +330,9 @@ bool ParseCMAP( const unsigned char* pCmap, int nLength, CmapResult& rResult )
         rtl_destroyTextToUnicodeConverter( aConverter );
 
         // convert the set of supported unicodes to ranges
-        typedef std::vector<sal_UCS4> Ucs4Vector;
-        Ucs4Vector aSupportedRanges;
+        std::vector<sal_UCS4> aSupportedRanges;
 
-        Ucs4Set::const_iterator itChar = aSupportedUnicodes.begin();
+        std::set<sal_UCS4>::const_iterator itChar = aSupportedUnicodes.begin();
         for(; itChar != aSupportedUnicodes.end(); ++itChar )
         {
             if( aSupportedRanges.empty()
@@ -361,7 +358,7 @@ bool ParseCMAP( const unsigned char* pCmap, int nLength, CmapResult& rResult )
         if( nRangeCount <= 0 )
             return false;
         pCodePairs = new sal_UCS4[ nRangeCount * 2 ];
-        Ucs4Vector::const_iterator itInt = aSupportedRanges.begin();
+        std::vector<sal_UCS4>::const_iterator itInt = aSupportedRanges.begin();
         for( pCP = pCodePairs; itInt != aSupportedRanges.end(); ++itInt )
             *(pCP++) = *itInt;
     }
@@ -373,7 +370,7 @@ bool ParseCMAP( const unsigned char* pCmap, int nLength, CmapResult& rResult )
     {
         pGlyphIds = new sal_uInt16[ aGlyphIdArray.size() ];
         sal_uInt16* pOut = pGlyphIds;
-        U16Vector::const_iterator it = aGlyphIdArray.begin();
+        std::vector<sal_uInt16>::const_iterator it = aGlyphIdArray.begin();
         while( it != aGlyphIdArray.end() )
             *(pOut++) = *(it++);
     }
diff --git a/vcl/source/fontsubset/cff.cxx b/vcl/source/fontsubset/cff.cxx
index 74725ea..9fcf8e7 100644
--- a/vcl/source/fontsubset/cff.cxx
+++ b/vcl/source/fontsubset/cff.cxx
@@ -36,7 +36,6 @@ typedef sal_Int32 GlyphWidth;
 typedef float RealType;
 typedef RealType ValType;
 #include <vector>
-typedef std::vector<ValType> ValVector;
 
 static const char* pStringIds[] = {
 /*0*/   ".notdef",      "space",            "exclam",           "quotedbl",
@@ -275,8 +274,8 @@ struct CffGlobal
     int     mnFontDictBase;
     int     mnFDAryCount;
 
-    ValVector   maFontBBox;
-    ValVector   maFontMatrix;
+    std::vector<ValType>   maFontBBox;
+    std::vector<ValType>   maFontMatrix;
 
     int     mnFontNameSID;
     int     mnFullNameSID;
@@ -300,12 +299,12 @@ struct CffLocal
     // ATM hinting related values
     ValType     maStemStdHW;
     ValType     maStemStdVW;
-    ValVector   maStemSnapH;
-    ValVector   maStemSnapV;
-    ValVector   maBlueValues;
-    ValVector   maOtherBlues;
-    ValVector   maFamilyBlues;
-    ValVector   maFamilyOtherBlues;
+    std::vector<ValType>   maStemSnapH;
+    std::vector<ValType>   maStemSnapV;
+    std::vector<ValType>   maBlueValues;
+    std::vector<ValType>   maOtherBlues;
+    std::vector<ValType>   maFamilyBlues;
+    std::vector<ValType>   maFamilyOtherBlues;
     RealType    mfBlueScale;
     RealType    mfBlueShift;
     RealType    mfBlueFuzz;
@@ -1712,7 +1711,7 @@ public:
     void        emitAllCrypted();
     int         tellPos() const;
     void        updateLen( int nTellPos, size_t nLength);
-    void        emitValVector( const char* pLineHead, const char* pLineTail, const ValVector&);
+    void        emitValVector( const char* pLineHead, const char* pLineTail, const std::vector<ValType>&);
 private:
     FILE*       mpFileOut;
     bool        mbCloseOutfile;
@@ -1844,7 +1843,7 @@ inline int dbl2str( char* pOut, double fVal)
 }
 
 void Type1Emitter::emitValVector( const char* pLineHead, const char* pLineTail,
-    const ValVector& rVector)
+    const std::vector<ValType>& rVector)
 {
     // ignore empty vectors
     if( rVector.empty())
@@ -1853,8 +1852,8 @@ void Type1Emitter::emitValVector( const char* pLineHead, const char* pLineTail,
     // emit the line head
     mpPtr += sprintf( mpPtr, "%s", pLineHead);
     // emit the vector values
-    ValVector::value_type aVal = 0;
-    for( ValVector::const_iterator it = rVector.begin();;) {
+    std::vector<ValType>::value_type aVal = 0;
+    for( std::vector<ValType>::const_iterator it = rVector.begin();;) {
         aVal = *it;
         if( ++it == rVector.end() )
             break;
diff --git a/vcl/source/fontsubset/gsub.cxx b/vcl/source/fontsubset/gsub.cxx
index 6ef40f2..52e6d8c 100644
--- a/vcl/source/fontsubset/gsub.cxx
+++ b/vcl/source/fontsubset/gsub.cxx
@@ -72,8 +72,7 @@ bool ReadGSUB( struct TrueTypeFont* pTTFile,
         if( nVersion != 0x00001000 )    // workaround for SunBatang etc.
             return false;               // unknown format or broken
 
-    typedef std::vector<sal_uInt32> ReqFeatureTagList;
-    ReqFeatureTagList aReqFeatureTagList;
+    std::vector<sal_uInt32> aReqFeatureTagList;
 
     aReqFeatureTagList.push_back( MKTAG("vert") );
 
@@ -231,8 +230,7 @@ bool ReadGSUB( struct TrueTypeFont* pTTFile,
             const sal_uInt16 nOfsCoverage       = NEXT_UShort( pSubLookup );
 
             typedef std::pair<sal_uInt16,sal_uInt16> GlyphSubst;
-            typedef std::vector<GlyphSubst> SubstVector;
-            SubstVector aSubstVector;
+            std::vector<GlyphSubst> aSubstVector;
 
             const FT_Byte* pCoverage    = pGsubBase
                 + nOfsLookupList + nOfsLookupTable + nOfsSubLookupTable + nOfsCoverage;
@@ -274,7 +272,7 @@ bool ReadGSUB( struct TrueTypeFont* pTTFile,
                 break;
             }
 
-            SubstVector::iterator subst_it( aSubstVector.begin() );
+            std::vector<GlyphSubst>::iterator subst_it( aSubstVector.begin() );
 
             switch( nFmtSubstitution )
             {
diff --git a/vcl/source/gdi/pdffontcache.hxx b/vcl/source/gdi/pdffontcache.hxx
index 8bf5c95..597c47f 100644
--- a/vcl/source/gdi/pdffontcache.hxx
+++ b/vcl/source/gdi/pdffontcache.hxx
@@ -51,7 +51,7 @@ namespace vcl
         };
         struct FontData
         {
-            Int32Vector  m_nWidths;
+            std::vector< sal_Int32 >  m_nWidths;
             Ucs2UIntMap  m_aGlyphIdToIndex;
         };
         typedef std::map< FontIdentifier, sal_uInt32 > FontToIndexMap;
diff --git a/vcl/source/gdi/pdfwriter_impl.cxx b/vcl/source/gdi/pdfwriter_impl.cxx
index b2edf76..1132b95 100644
--- a/vcl/source/gdi/pdfwriter_impl.cxx
+++ b/vcl/source/gdi/pdfwriter_impl.cxx
@@ -2959,7 +2959,7 @@ std::map< sal_Int32, sal_Int32 > PDFWriterImpl::emitSystemFont( const PhysicalFo
     else if( pFont->CanSubset() )
     {
         aSubType = OString( "/TrueType" );
-        Int32Vector aGlyphWidths;
+        std::vector< sal_Int32 > aGlyphWidths;
         Ucs2UIntMap aUnicodeMap;
         pGraphics->GetGlyphWidths( pFont, false, aGlyphWidths, aUnicodeMap );
 
@@ -3893,7 +3893,7 @@ bool PDFWriterImpl::emitFonts()
     osl_createTempFile( nullptr, nullptr, &aTmpName.pData );
     for( FontSubsetData::iterator it = m_aSubsets.begin(); it != m_aSubsets.end(); ++it )
     {
-        for( FontEmitList::iterator lit = it->second.m_aSubsets.begin(); lit != it->second.m_aSubsets.end(); ++lit )
+        for( std::list< FontEmit >::iterator lit = it->second.m_aSubsets.begin(); lit != it->second.m_aSubsets.end(); ++lit )
         {
             sal_GlyphId aGlyphIds[ 256 ];
             sal_Int32 pWidths[ 256 ];
diff --git a/vcl/source/gdi/pdfwriter_impl.hxx b/vcl/source/gdi/pdfwriter_impl.hxx
index 8cc2d68..5f3ef73 100644
--- a/vcl/source/gdi/pdfwriter_impl.hxx
+++ b/vcl/source/gdi/pdfwriter_impl.hxx
@@ -306,7 +306,6 @@ public:
 
         explicit FontEmit( sal_Int32 nID ) : m_nFontID( nID ) {}
     };
-    typedef std::list< FontEmit > FontEmitList;
     struct Glyph
     {
         sal_Int32   m_nFontID;
@@ -315,7 +314,7 @@ public:
     typedef std::map< sal_GlyphId, Glyph > FontMapping;
     struct FontSubset
     {
-        FontEmitList        m_aSubsets;
+        std::list< FontEmit >        m_aSubsets;
         FontMapping         m_aMapping;
     };
     typedef std::map< const PhysicalFontFace*, FontSubset > FontSubsetData;
diff --git a/vcl/source/gdi/sallayout.cxx b/vcl/source/gdi/sallayout.cxx
index 6caf2fd..1ec7a08 100644
--- a/vcl/source/gdi/sallayout.cxx
+++ b/vcl/source/gdi/sallayout.cxx
@@ -787,7 +787,7 @@ bool GenericSalLayout::GetCharWidths( DeviceCoordinate* pCharWidths ) const
         pCharWidths[n] = 0;
 
     // determine cluster extents
-    for( GlyphVector::const_iterator pGlyphIter = m_GlyphItems.begin(), end = m_GlyphItems.end(); pGlyphIter != end ; ++pGlyphIter)
+    for( std::vector<GlyphItem>::const_iterator pGlyphIter = m_GlyphItems.begin(), end = m_GlyphItems.end(); pGlyphIter != end ; ++pGlyphIter)
     {
         // use cluster start to get char index
         if( !pGlyphIter->IsClusterStart() )
@@ -829,7 +829,7 @@ bool GenericSalLayout::GetCharWidths( DeviceCoordinate* pCharWidths ) const
         // rightmost cluster edge is the leftmost edge of next cluster
         // for clusters that do not have x-sorted glyphs
         // TODO: avoid recalculation of left bound in next cluster iteration
-        for( GlyphVector::const_iterator pN = pGlyphIter; ++pN != end; )
+        for( std::vector<GlyphItem>::const_iterator pN = pGlyphIter; ++pN != end; )
         {
             if( pN->IsClusterStart() )
                 break;
@@ -872,7 +872,7 @@ DeviceCoordinate GenericSalLayout::GetTextWidth() const
     DeviceCoordinate nMinPos = 0;
     DeviceCoordinate nMaxPos = 0;
 
-    for( GlyphVector::const_iterator pGlyphIter = m_GlyphItems.begin(), end = m_GlyphItems.end(); pGlyphIter != end ; ++pGlyphIter )
+    for( std::vector<GlyphItem>::const_iterator pGlyphIter = m_GlyphItems.begin(), end = m_GlyphItems.end(); pGlyphIter != end ; ++pGlyphIter )
     {
         // update the text extent with the glyph extent
         DeviceCoordinate nXPos = pGlyphIter->maLinearPos.X();
@@ -1050,9 +1050,9 @@ void GenericSalLayout::Justify( DeviceCoordinate nNewWidth )
         return;
     }
     // find rightmost glyph, it won't get stretched
-    GlyphVector::iterator pGlyphIterRight = m_GlyphItems.begin();
+    std::vector<GlyphItem>::iterator pGlyphIterRight = m_GlyphItems.begin();
     pGlyphIterRight += m_GlyphItems.size() - 1;
-    GlyphVector::iterator pGlyphIter;
+    std::vector<GlyphItem>::iterator pGlyphIter;
     // count stretchable glyphs
     int nStretchable = 0;
     int nMaxGlyphWidth = 0;
@@ -1119,7 +1119,7 @@ void GenericSalLayout::ApplyAsianKerning(const OUString& rStr)
     const int nLength = rStr.getLength();
     long nOffset = 0;
 
-    for( GlyphVector::iterator pGlyphIter = m_GlyphItems.begin(), pGlyphIterEnd = m_GlyphItems.end(); pGlyphIter != pGlyphIterEnd; ++pGlyphIter )
+    for( std::vector<GlyphItem>::iterator pGlyphIter = m_GlyphItems.begin(), pGlyphIterEnd = m_GlyphItems.end(); pGlyphIter != pGlyphIterEnd; ++pGlyphIter )
     {
         const int n = pGlyphIter->mnCharPos;
         if( n < nLength - 1)
@@ -1165,7 +1165,7 @@ void GenericSalLayout::KashidaJustify( long nKashidaIndex, int nKashidaWidth )
 
     // calculate max number of needed kashidas
     int nKashidaCount = 0;
-    for (GlyphVector::iterator pGlyphIter = m_GlyphItems.begin();
+    for (std::vector<GlyphItem>::iterator pGlyphIter = m_GlyphItems.begin();
             pGlyphIter != m_GlyphItems.end(); ++pGlyphIter)
     {
         // only inject kashidas in RTL contexts
@@ -1185,7 +1185,7 @@ void GenericSalLayout::KashidaJustify( long nKashidaIndex, int nKashidaWidth )
         Point aPos = pGlyphIter->maLinearPos;
         aPos.X() -= nGapWidth; // cluster is already right aligned
         int const nCharPos = pGlyphIter->mnCharPos;
-        GlyphVector::iterator pGlyphIter2 = pGlyphIter;
+        std::vector<GlyphItem>::iterator pGlyphIter2 = pGlyphIter;
         for(; nGapWidth > nKashidaWidth; nGapWidth -= nKashidaWidth, ++nKashidaCount )
         {
             pGlyphIter2 = m_GlyphItems.insert(pGlyphIter2, GlyphItem(nCharPos, nKashidaIndex, aPos,
@@ -1213,7 +1213,7 @@ void GenericSalLayout::GetCaretPositions( int nMaxIndex, long* pCaretXArray ) co
         pCaretXArray[i] = -1;
 
     // calculate caret positions using glyph array
-    for( GlyphVector::const_iterator pGlyphIter = m_GlyphItems.begin(), pGlyphIterEnd = m_GlyphItems.end(); pGlyphIter != pGlyphIterEnd; ++pGlyphIter )
+    for( std::vector<GlyphItem>::const_iterator pGlyphIter = m_GlyphItems.begin(), pGlyphIterEnd = m_GlyphItems.end(); pGlyphIter != pGlyphIterEnd; ++pGlyphIter )
     {
         long nXPos = pGlyphIter->maLinearPos.X();
         long nXRight = nXPos + pGlyphIter->mnOrigWidth;
@@ -1260,8 +1260,8 @@ int GenericSalLayout::GetNextGlyphs( int nLen, sal_GlyphId* pGlyphs, Point& rPos
                                      int& nStart, DeviceCoordinate* pGlyphAdvAry, int* pCharPosAry,
                                      const PhysicalFontFace** /*pFallbackFonts*/ ) const
 {
-    GlyphVector::const_iterator pGlyphIter = m_GlyphItems.begin();
-    GlyphVector::const_iterator pGlyphIterEnd = m_GlyphItems.end();
+    std::vector<GlyphItem>::const_iterator pGlyphIter = m_GlyphItems.begin();
+    std::vector<GlyphItem>::const_iterator pGlyphIterEnd = m_GlyphItems.end();
     pGlyphIter += nStart;
 
     // find next glyph in substring
@@ -1347,7 +1347,7 @@ void GenericSalLayout::MoveGlyph( int nStart, long nNewXPos )
     if( nStart >= (int)m_GlyphItems.size() )
         return;
 
-    GlyphVector::iterator pGlyphIter = m_GlyphItems.begin();
+    std::vector<GlyphItem>::iterator pGlyphIter = m_GlyphItems.begin();
     pGlyphIter += nStart;
 
     // the nNewXPos argument determines the new cell position
@@ -1360,7 +1360,7 @@ void GenericSalLayout::MoveGlyph( int nStart, long nNewXPos )
     // adjust all following glyph positions if needed
     if( nXDelta != 0 )
     {
-        for( GlyphVector::iterator pGlyphIterEnd = m_GlyphItems.end(); pGlyphIter != pGlyphIterEnd; ++pGlyphIter )
+        for( std::vector<GlyphItem>::iterator pGlyphIterEnd = m_GlyphItems.end(); pGlyphIter != pGlyphIterEnd; ++pGlyphIter )
         {
             pGlyphIter->maLinearPos.X() += nXDelta;
         }
@@ -1372,7 +1372,7 @@ void GenericSalLayout::DropGlyph( int nStart )
     if( nStart >= (int)m_GlyphItems.size())
         return;
 
-    GlyphVector::iterator pGlyphIter = m_GlyphItems.begin();
+    std::vector<GlyphItem>::iterator pGlyphIter = m_GlyphItems.begin();
     pGlyphIter += nStart;
     pGlyphIter->maGlyphId = GF_DROPPED;
     pGlyphIter->mnCharPos = -1;
@@ -1404,14 +1404,14 @@ void GenericSalLayout::SortGlyphItems()
     // move cluster components behind their cluster start (especially for RTL)
     // using insertion sort because the glyph items are "almost sorted"
 
-    for( GlyphVector::iterator pGlyphIter = m_GlyphItems.begin(), pGlyphIterEnd = m_GlyphItems.end(); pGlyphIter != pGlyphIterEnd; ++pGlyphIter )
+    for( std::vector<GlyphItem>::iterator pGlyphIter = m_GlyphItems.begin(), pGlyphIterEnd = m_GlyphItems.end(); pGlyphIter != pGlyphIterEnd; ++pGlyphIter )
     {
         // find a cluster starting with a diacritic
         if( !pGlyphIter->IsDiacritic() )
             continue;
         if( !pGlyphIter->IsClusterStart() )
             continue;
-        for( GlyphVector::iterator pBaseGlyph = pGlyphIter; ++pBaseGlyph != pGlyphIterEnd; )
+        for( std::vector<GlyphItem>::iterator pBaseGlyph = pGlyphIter; ++pBaseGlyph != pGlyphIterEnd; )
         {
             // find the base glyph matching to the misplaced diacritic
             if( pBaseGlyph->IsClusterStart() )
diff --git a/vcl/source/image/ImplImageList.cxx b/vcl/source/image/ImplImageList.cxx
index 56750f5..a089004 100644
--- a/vcl/source/image/ImplImageList.cxx
+++ b/vcl/source/image/ImplImageList.cxx
@@ -40,7 +40,7 @@ ImplImageList::ImplImageList( const ImplImageList &aSrc )
     , mnRefCount(1)
 {
     maImages.reserve( aSrc.maImages.size() );
-    for ( ImageAryDataVec::const_iterator aIt = aSrc.maImages.begin(), aEnd = aSrc.maImages.end(); aIt != aEnd; ++aIt )
+    for ( std::vector<ImageAryData *>::const_iterator aIt = aSrc.maImages.begin(), aEnd = aSrc.maImages.end(); aIt != aEnd; ++aIt )
     {
         ImageAryData* pAryData = new ImageAryData( **aIt );
         maImages.push_back( pAryData );
@@ -51,7 +51,7 @@ ImplImageList::ImplImageList( const ImplImageList &aSrc )
 
 ImplImageList::~ImplImageList()
 {
-    for ( ImageAryDataVec::iterator aIt = maImages.begin(), aEnd = maImages.end(); aIt != aEnd; ++aIt )
+    for ( std::vector<ImageAryData *>::iterator aIt = maImages.begin(), aEnd = maImages.end(); aIt != aEnd; ++aIt )
         delete *aIt;
 }
 
diff --git a/vcl/source/outdev/font.cxx b/vcl/source/outdev/font.cxx
index 022ba44..388b9b5 100644
--- a/vcl/source/outdev/font.cxx
+++ b/vcl/source/outdev/font.cxx
@@ -720,7 +720,7 @@ void OutputDevice::RemoveFontSubstitute( sal_uInt16 n )
 
 void ImplDirectFontSubstitution::RemoveFontSubstitute( int nIndex )
 {
-    FontSubstList::iterator it = maFontSubstList.begin();
+    std::list<ImplFontSubstEntry>::iterator it = maFontSubstList.begin();
     for( int nCount = 0; (it != maFontSubstList.end()) && (nCount++ != nIndex); ++it ) ;
     if( it != maFontSubstList.end() )
         maFontSubstList.erase( it );
@@ -739,7 +739,7 @@ bool ImplDirectFontSubstitution::FindFontSubstitute( OUString& rSubstName,
     const OUString& rSearchName ) const
 {
     // TODO: get rid of O(N) searches
-    FontSubstList::const_iterator it = maFontSubstList.begin();
+    std::list<ImplFontSubstEntry>::const_iterator it = maFontSubstList.begin();
     for(; it != maFontSubstList.end(); ++it )
     {
         const ImplFontSubstEntry& rEntry = *it;
diff --git a/vcl/source/window/debugevent.cxx b/vcl/source/window/debugevent.cxx
index cff4d02..4bdc65a 100644
--- a/vcl/source/window/debugevent.cxx
+++ b/vcl/source/window/debugevent.cxx
@@ -57,9 +57,8 @@ vcl::Window *DebugEventInjector::ChooseWindow()
     return aChildren[ aChildren.size() * getRandom() ];
 }
 
-typedef std::vector< SalMenuEvent > MenuItemIds;
 
-static void CollectMenuItemIds( Menu *pMenu, MenuItemIds &rIds )
+static void CollectMenuItemIds( Menu *pMenu, std::vector< SalMenuEvent > &rIds )
 {
     sal_uInt16 nItems = pMenu->GetItemCount();
     for (sal_uInt16 i = 0; i < nItems; i++)
@@ -99,7 +98,7 @@ void DebugEventInjector::InjectMenuEvent()
         SalEvent::MenuButtonCommand,
     };
 
-    MenuItemIds aIds;
+    std::vector< SalMenuEvent > aIds;
     CollectMenuItemIds( pMenuBar, aIds );
 
     SalEvent nEvent = nEvents[ (int)(getRandom() * SAL_N_ELEMENTS( nEvents )) ];
diff --git a/vcl/source/window/splitwin.cxx b/vcl/source/window/splitwin.cxx
index 752e193..21dfa64 100644
--- a/vcl/source/window/splitwin.cxx
+++ b/vcl/source/window/splitwin.cxx
@@ -80,7 +80,6 @@ public:
     long                mnMaxSize;
 };
 
-typedef std::vector< ImplSplitItem* > ImplSplitItems;
 
 class ImplSplitSet
 {
@@ -89,7 +88,7 @@ public:
     ~ImplSplitSet();
     void dispose();
 
-    ImplSplitItems      mpItems;
+    std::vector< ImplSplitItem* >      mpItems;
     Wallpaper*          mpWallpaper;
     Bitmap*             mpBitmap;
     long                mnLastSize;
@@ -341,7 +340,7 @@ static ImplSplitSet* ImplFindSet( ImplSplitSet* pSet, sal_uInt16 nId )
 
     sal_uInt16          i;
     size_t              nItems = pSet->mpItems.size();
-    ImplSplitItems&     rItems = pSet->mpItems;
+    std::vector< ImplSplitItem* >&     rItems = pSet->mpItems;
 
     for ( i = 0; i < nItems; i++ )
     {
@@ -366,7 +365,7 @@ static ImplSplitSet* ImplFindItem( ImplSplitSet* pSet, sal_uInt16 nId, sal_uInt1
 {
     sal_uInt16          i;
     size_t              nItems = pSet->mpItems.size();
-    ImplSplitItems&     rItems = pSet->mpItems;
+    std::vector< ImplSplitItem* >&     rItems = pSet->mpItems;
 
     for ( i = 0; i < nItems; i++ )
     {
@@ -394,7 +393,7 @@ static sal_uInt16 ImplFindItem( ImplSplitSet* pSet, vcl::Window* pWindow )
 {
     sal_uInt16          i;
     size_t              nItems = pSet->mpItems.size();
-    ImplSplitItems&     rItems = pSet->mpItems;
+    std::vector< ImplSplitItem* >&     rItems = pSet->mpItems;
 
     for ( i = 0; i < nItems; i++ )
     {
@@ -419,7 +418,7 @@ static sal_uInt16 ImplFindItem( ImplSplitSet* pSet, const Point& rPos,
 {
     sal_uInt16          i;
     size_t              nItems = pSet->mpItems.size();
-    ImplSplitItems&     rItems = pSet->mpItems;
+    std::vector< ImplSplitItem* >&     rItems = pSet->mpItems;
 
     for ( i = 0; i < nItems; i++ )
     {
@@ -477,7 +476,7 @@ static void ImplCalcSet( ImplSplitSet* pSet,
     long                nCalcSize;
     long                nPos;
     long                nMaxPos;
-    ImplSplitItems&     rItems = pSet->mpItems;
+    std::vector< ImplSplitItem* >&     rItems = pSet->mpItems;
     bool                bEmpty;
 
     // get number of visible items
@@ -827,7 +826,7 @@ void SplitWindow::ImplCalcSet2( SplitWindow* pWindow, ImplSplitSet* pSet, bool b
 {
     sal_uInt16          i;
     size_t              nItems = pSet->mpItems.size();
-    ImplSplitItems&     rItems = pSet->mpItems;
+    std::vector< ImplSplitItem* >&     rItems = pSet->mpItems;
 
     if ( pWindow->IsReallyVisible() && pWindow->IsUpdateMode() && pWindow->mbInvalidate )
     {
@@ -923,7 +922,7 @@ void SplitWindow::ImplCalcSet2( SplitWindow* pWindow, ImplSplitSet* pSet, bool b
     }
 }
 
-static void ImplCalcLogSize( ImplSplitItems rItems, size_t nItems )
+static void ImplCalcLogSize( std::vector< ImplSplitItem* > rItems, size_t nItems )
 {
     // update original sizes
     size_t  i;
@@ -992,7 +991,7 @@ void SplitWindow::ImplDrawBack(vcl::RenderContext& rRenderContext, ImplSplitSet*
 {
     sal_uInt16      i;
     size_t          nItems = pSet->mpItems.size();
-    ImplSplitItems& rItems = pSet->mpItems;
+    std::vector< ImplSplitItem* >& rItems = pSet->mpItems;
 
     // also draw background for mainset
     if (pSet->mnId == 0)
@@ -1039,7 +1038,7 @@ static void ImplDrawSplit(vcl::RenderContext& rRenderContext, ImplSplitSet* pSet
     long       nPos;
     long       nTop;
     long       nBottom;
-    ImplSplitItems& rItems = pSet->mpItems;
+    std::vector< ImplSplitItem* >& rItems = pSet->mpItems;
     const StyleSettings& rStyleSettings = rRenderContext.GetSettings().GetStyleSettings();
 
     for (i = 0; i < nItems-1; i++)
@@ -1140,7 +1139,7 @@ sal_uInt16 SplitWindow::ImplTestSplit( ImplSplitSet* pSet, const Point& rPos,
     long            nPos;
     long            nTop;
     long            nBottom;
-    ImplSplitItems& rItems = pSet->mpItems;
+    std::vector< ImplSplitItem* >& rItems = pSet->mpItems;
 
     if ( bRows )
     {
@@ -2177,7 +2176,7 @@ void SplitWindow::ImplStartSplit( const MouseEvent& rMEvt )
         }
         else
         {
-            ImplSplitItems&  rItems = mpSplitSet->mpItems;
+            std::vector< ImplSplitItem* >&  rItems = mpSplitSet->mpItems;
             sal_uInt16       nItems = mpSplitSet->mpItems.size();
             mpLastSizes = new long[nItems*2];
             for ( sal_uInt16 i = 0; i < nItems; i++ )
@@ -2418,7 +2417,7 @@ void SplitWindow::Tracking( const TrackingEvent& rTEvt )
             {
                 if ( rTEvt.IsTrackingCanceled() )
                 {
-                    ImplSplitItems& rItems = mpSplitSet->mpItems;
+                    std::vector< ImplSplitItem* >& rItems = mpSplitSet->mpItems;
                     size_t          nItems = rItems.size();
                     for ( size_t i = 0; i < nItems; i++ )
                     {
@@ -2784,7 +2783,7 @@ void SplitWindow::SplitItem( sal_uInt16 nId, long nNewSize,
         return;
 
     size_t           nItems = pSet->mpItems.size();
-    ImplSplitItems&  rItems = pSet->mpItems;
+    std::vector< ImplSplitItem* >&  rItems = pSet->mpItems;
 
     // When there is an explicit minimum or maximum size then move nNewSize
     // into that range (when it is not yet already in it.)
@@ -3050,7 +3049,7 @@ long SplitWindow::GetItemSize( sal_uInt16 nId, SplitWindowItemFlags nBits ) cons
             SplitWindowItemFlags nTempBits;
             sal_uInt16              i;
             nItems = pSet->mpItems.size();
-            ImplSplitItems& rItems = pSet->mpItems;
+            std::vector< ImplSplitItem* >& rItems = pSet->mpItems;
             for ( i = 0; i < nItems; i++ )
             {
                 if ( i == nPos )
diff --git a/vcl/unx/generic/fontmanager/fontcache.cxx b/vcl/unx/generic/fontmanager/fontcache.cxx
index a4a1550..27851c1 100644
--- a/vcl/unx/generic/fontmanager/fontcache.cxx
+++ b/vcl/unx/generic/fontmanager/fontcache.cxx
@@ -76,7 +76,7 @@ void FontCache::clearCache()
     {
         for( FontDirMap::iterator entry_it = dir_it->second.m_aEntries.begin(); entry_it != dir_it->second.m_aEntries.end(); ++entry_it )
         {
-            for( FontCacheEntry::iterator font_it = entry_it->second.m_aEntry.begin(); font_it != entry_it->second.m_aEntry.end(); ++font_it )
+            for( std::list< PrintFontManager::PrintFont* >::iterator font_it = entry_it->second.m_aEntry.begin(); font_it != entry_it->second.m_aEntry.end(); ++font_it )
                 delete *font_it;
         }
     }
@@ -124,7 +124,7 @@ void FontCache::flush()
         for( FontDirMap::const_iterator entry_it = rDir.begin(); entry_it != rDir.end(); ++entry_it )
         {
             // insert cache entries
-            const FontCacheEntry& rEntry( entry_it->second.m_aEntry );
+            const std::list< PrintFontManager::PrintFont* >& rEntry( entry_it->second.m_aEntry );
             if( rEntry.empty() )
                 continue;
 
@@ -140,7 +140,7 @@ void FontCache::flush()
             aStream.WriteLine(aLine.makeStringAndClear());
 
             sal_Int32 nSubEntry = 0;
-            for( FontCacheEntry::const_iterator it = rEntry.begin(); it != rEntry.end(); ++it, nSubEntry++ )
+            for( std::list< PrintFontManager::PrintFont* >::const_iterator it = rEntry.begin(); it != rEntry.end(); ++it, nSubEntry++ )
             {
                 /*
                  *  for each font entry write:
@@ -463,7 +463,7 @@ void FontCache::read()
                     continue;
                 }
 
-                FontCacheEntry& rEntry = (*pDir)[aFile].m_aEntry;
+                std::list< PrintFontManager::PrintFont* >& rEntry = (*pDir)[aFile].m_aEntry;
                 rEntry.push_back( pFont );
             }
         }
@@ -611,7 +611,7 @@ bool FontCache::getFontCacheFile( int nDirID, const OString& rFile, list< PrintF
         FontDirMap::const_iterator entry = dir->second.m_aEntries.find( rFile );
         if( entry != dir->second.m_aEntries.end() )
         {
-            for( FontCacheEntry::const_iterator font = entry->second.m_aEntry.begin(); font != entry->second.m_aEntry.end(); ++font )
+            for( std::list< PrintFontManager::PrintFont* >::const_iterator font = entry->second.m_aEntry.begin(); font != entry->second.m_aEntry.end(); ++font )
             {
                 bSuccess = true;
                 PrintFontManager::PrintFont* pFont = clonePrintFont( *font );
@@ -644,7 +644,7 @@ void FontCache::updateFontCacheEntry( const PrintFontManager::PrintFont* pFont,
     }
     FontCacheData::const_iterator dir = m_aCache.find( nDirID );
     FontDirMap::const_iterator entry;
-    FontCacheEntry::const_iterator font;
+    std::list< PrintFontManager::PrintFont* >::const_iterator font;
     PrintFontManager::PrintFont* pCacheFont = nullptr;
 
     if( dir != m_aCache.end() )
@@ -700,7 +700,7 @@ bool FontCache::listDirectory( const OString& rDir, std::list< PrintFontManager:
     {
         for( FontDirMap::const_iterator file = dir->second.m_aEntries.begin(); file != dir->second.m_aEntries.end(); ++file )
         {
-            for( FontCacheEntry::const_iterator font = file->second.m_aEntry.begin(); font != file->second.m_aEntry.end(); ++font )
+            for( std::list< PrintFontManager::PrintFont* >::const_iterator font = file->second.m_aEntry.begin(); font != file->second.m_aEntry.end(); ++font )
             {
                 PrintFontManager::PrintFont* pFont = clonePrintFont( *font );
                 rNewFonts.push_back( pFont );
diff --git a/vcl/unx/generic/gdi/cairotextrender.cxx b/vcl/unx/generic/gdi/cairotextrender.cxx
index 513f5e5..d1ad180 100644
--- a/vcl/unx/generic/gdi/cairotextrender.cxx
+++ b/vcl/unx/generic/gdi/cairotextrender.cxx
@@ -593,7 +593,7 @@ const Ucs2SIntMap* CairoTextRender::GetFontEncodingVector( const PhysicalFontFac
 
 void CairoTextRender::GetGlyphWidths( const PhysicalFontFace* pFont,
                                    bool bVertical,
-                                   Int32Vector& rWidths,
+                                   std::vector< sal_Int32 >& rWidths,
                                    Ucs2UIntMap& rUnicodeEnc )
 {
     // in this context the pFont->GetFontId() is a valid PSP
diff --git a/vcl/unx/generic/gdi/font.cxx b/vcl/unx/generic/gdi/font.cxx
index 1669465..3cc6510 100644
--- a/vcl/unx/generic/gdi/font.cxx
+++ b/vcl/unx/generic/gdi/font.cxx
@@ -157,7 +157,7 @@ const Ucs2SIntMap* X11SalGraphics::GetFontEncodingVector( const PhysicalFontFace
 
 void X11SalGraphics::GetGlyphWidths( const PhysicalFontFace* pFont,
                                    bool bVertical,
-                                   Int32Vector& rWidths,
+                                   std::vector< sal_Int32 >& rWidths,
                                    Ucs2UIntMap& rUnicodeEnc )
 {
     mxTextRenderImpl->GetGlyphWidths(pFont, bVertical, rWidths, rUnicodeEnc);
diff --git a/vcl/unx/generic/glyphs/freetype_glyphcache.cxx b/vcl/unx/generic/glyphs/freetype_glyphcache.cxx
index e12fcb8..3db03a2 100644
--- a/vcl/unx/generic/glyphs/freetype_glyphcache.cxx
+++ b/vcl/unx/generic/glyphs/freetype_glyphcache.cxx
@@ -1307,8 +1307,7 @@ void ServerFont::ApplyGSUB( const FontSelectPattern& rFSD )
 {
 #define MKTAG(s) ((((((s[0]<<8)+s[1])<<8)+s[2])<<8)+s[3])
 
-    typedef std::vector<sal_uLong> ReqFeatureTagList;
-    ReqFeatureTagList aReqFeatureTagList;
+    std::vector<sal_uInt32> aReqFeatureTagList;
     if( rFSD.mbVertical )
         aReqFeatureTagList.push_back( MKTAG("vert") );
     // TODO: request more features depending on script and language system
@@ -1458,8 +1457,7 @@ void ServerFont::ApplyGSUB( const FontSelectPattern& rFSD )
             pSubLookup += 4;
 
             typedef std::pair<sal_uInt16,sal_uInt16> GlyphSubst;
-            typedef std::vector<GlyphSubst> SubstVector;
-            SubstVector aSubstVector;
+            std::vector<GlyphSubst> aSubstVector;
 
             const FT_Byte* pCoverage    = pGsubBase + nOfsLookupList + nOfsLookupTable + nOfsSubLookupTable + nOfsCoverage;
             const sal_uInt16 nFmtCoverage   = GetUShort( pCoverage+0 );
@@ -1497,7 +1495,7 @@ void ServerFont::ApplyGSUB( const FontSelectPattern& rFSD )
                     break;
             }
 
-            SubstVector::iterator it( aSubstVector.begin() );
+            std::vector<GlyphSubst>::iterator it( aSubstVector.begin() );
 
             switch( nFmtSubstitution )
             {
diff --git a/vcl/unx/generic/print/genpspgraphics.cxx b/vcl/unx/generic/print/genpspgraphics.cxx
index 9c03285..2d8461ad 100644
--- a/vcl/unx/generic/print/genpspgraphics.cxx
+++ b/vcl/unx/generic/print/genpspgraphics.cxx
@@ -1049,7 +1049,7 @@ const Ucs2SIntMap* GenPspGraphics::GetFontEncodingVector( const PhysicalFontFace
 
 void GenPspGraphics::GetGlyphWidths( const PhysicalFontFace* pFont,
                                   bool bVertical,
-                                  Int32Vector& rWidths,
+                                  std::vector< sal_Int32 >& rWidths,
                                   Ucs2UIntMap& rUnicodeEnc )
 {
     // in this context the pFont->GetFontId() is a valid PSP
@@ -1078,7 +1078,7 @@ const Ucs2SIntMap* GenPspGraphics::DoGetFontEncodingVector( fontID aFont, const
 
 void GenPspGraphics::DoGetGlyphWidths( psp::fontID aFont,
                                     bool bVertical,
-                                    Int32Vector& rWidths,
+                                    std::vector< sal_Int32 >& rWidths,
                                     Ucs2UIntMap& rUnicodeEnc )
 {
     psp::PrintFontManager& rMgr = psp::PrintFontManager::get();
diff --git a/vcl/unx/gtk/salnativewidgets-gtk.cxx b/vcl/unx/gtk/salnativewidgets-gtk.cxx
index e3badbc..96f6885 100644
--- a/vcl/unx/gtk/salnativewidgets-gtk.cxx
+++ b/vcl/unx/gtk/salnativewidgets-gtk.cxx
@@ -911,7 +911,7 @@ bool GtkSalGraphics::drawNativeControl(ControlType nType, ControlPart nPart,
         return true;
     }
 
-    clipList aClip;
+    std::list< Rectangle > aClip;
     int nPasses = 0;
     GdkDrawable* gdkDrawable[2];
     std::unique_ptr<GdkX11Pixmap> xPixmap;
@@ -992,7 +992,7 @@ bool GtkSalGraphics::DoDrawNativeControl(
                             ControlType nType,
                             ControlPart nPart,
                             const Rectangle& aCtrlRect,
-                            const clipList& aClip,
+                            const std::list< Rectangle >& aClip,
                             ControlState nState,
                             const ImplControlValue& aValue,
                             const OUString& rCaption,
@@ -1430,7 +1430,7 @@ bool GtkSalGraphics::NWPaintGTKArrow(
             GdkDrawable* gdkDrawable,
             ControlType, ControlPart,
             const Rectangle& rControlRectangle,
-            const clipList& rClipList,
+            const std::list< Rectangle >& rClipList,
             ControlState nState, const ImplControlValue& aValue,
             const OUString& )
 {
@@ -1438,7 +1438,7 @@ bool GtkSalGraphics::NWPaintGTKArrow(
     GtkStateType stateType(nState&ControlState::PRESSED?GTK_STATE_ACTIVE:GTK_STATE_NORMAL);
 
     GdkRectangle clipRect;
-    for( clipList::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
+    for( std::list< Rectangle >::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
     {
         clipRect.x = it->Left();
         clipRect.y = it->Top();
@@ -1459,7 +1459,7 @@ bool GtkSalGraphics::NWPaintGTKListHeader(
             GdkDrawable* gdkDrawable,
             ControlType, ControlPart,
             const Rectangle& rControlRectangle,
-            const clipList& rClipList,
+            const std::list< Rectangle >& rClipList,
             ControlState nState, const ImplControlValue&,
             const OUString& )
 {
@@ -1479,7 +1479,7 @@ bool GtkSalGraphics::NWPaintGTKListHeader(
     NWSetWidgetState( button, nState, stateType );
 
     GdkRectangle clipRect;
-    for( clipList::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
+    for( std::list< Rectangle >::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
     {
         clipRect.x = it->Left();
         clipRect.y = it->Top();
@@ -1500,7 +1500,7 @@ bool GtkSalGraphics::NWPaintGTKFixedLine(
             GdkDrawable* gdkDrawable,
             ControlType, ControlPart nPart,
             const Rectangle& rControlRectangle,
-            const clipList&,
+            const std::list< Rectangle >&,
             ControlState, const ImplControlValue&,
             const OUString& )
 {
@@ -1516,7 +1516,7 @@ bool GtkSalGraphics::NWPaintGTKFrame(
             GdkDrawable* gdkDrawable,
             ControlType, ControlPart,
             const Rectangle& rControlRectangle,
-            const clipList& rClipList,
+            const std::list< Rectangle >& rClipList,
             ControlState /* nState */, const ImplControlValue& aValue,
             const OUString& )
 {
@@ -1529,7 +1529,7 @@ bool GtkSalGraphics::NWPaintGTKFrame(
     if( nStyle == DrawFrameStyle::Out )
         shadowType=GTK_SHADOW_IN;
 
-    for( clipList::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
+    for( std::list< Rectangle >::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
     {
         clipRect.x = it->Left();
         clipRect.y = it->Top();
@@ -1583,12 +1583,12 @@ bool GtkSalGraphics::NWPaintGTKWindowBackground(
             GdkDrawable* gdkDrawable,
             ControlType, ControlPart,
             const Rectangle& rControlRectangle,
-            const clipList& rClipList,
+            const std::list< Rectangle >& rClipList,
             ControlState /* nState */, const ImplControlValue&,
             const OUString& )
 {
     GdkRectangle clipRect;
-    for( clipList::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
+    for( std::list< Rectangle >::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
     {
         clipRect.x = it->Left();
         clipRect.y = it->Top();
@@ -1611,7 +1611,7 @@ bool GtkSalGraphics::NWPaintGTKButtonReal(
             GdkDrawable* gdkDrawable,
             ControlType, ControlPart,
             const Rectangle& rControlRectangle,
-            const clipList& rClipList,
+            const std::list< Rectangle >& rClipList,
             ControlState nState, const ImplControlValue&,
             const OUString& )
 {
@@ -1707,7 +1707,7 @@ bool GtkSalGraphics::NWPaintGTKButtonReal(
         wi -= 2 * (focusWidth + focusPad);
         hi -= 2 * (focusWidth + focusPad);
     }
-    for( clipList::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it)
+    for( std::list< Rectangle >::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it)
     {
         clipRect.x = it->Left();
         clipRect.y = it->Top();
@@ -1747,7 +1747,7 @@ bool GtkSalGraphics::NWPaintGTKButton(
             GdkDrawable* gdkDrawable,
             ControlType type, ControlPart part,
             const Rectangle& rControlRectangle,
-            const clipList& rClipList,
+            const std::list< Rectangle >& rClipList,
             ControlState nState, const ImplControlValue& value,
             const OUString& string)
 {
@@ -1837,7 +1837,7 @@ static Rectangle NWGetTabItemRect( SalX11Screen nScreen, Rectangle aAreaRect )
 bool GtkSalGraphics::NWPaintGTKRadio( GdkDrawable* gdkDrawable,
                                       ControlType, ControlPart,
                                       const Rectangle& rControlRectangle,
-                                      const clipList& rClipList,
+                                      const std::list< Rectangle >& rClipList,
                                       ControlState nState,
                                       const ImplControlValue& aValue,
                                       const OUString& )
@@ -1875,7 +1875,7 @@ bool GtkSalGraphics::NWPaintGTKRadio( GdkDrawable* gdkDrawable,
         GTK_TOGGLE_BUTTON(gWidgetData[m_nXScreen].gRadioWidgetSibling)->active = true;
     GTK_TOGGLE_BUTTON(gWidgetData[m_nXScreen].gRadioWidget)->active = isChecked;
 
-    for( clipList::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
+    for( std::list< Rectangle >::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
     {
         clipRect.x = it->Left();
         clipRect.y = it->Top();
@@ -1893,7 +1893,7 @@ bool GtkSalGraphics::NWPaintGTKRadio( GdkDrawable* gdkDrawable,
 bool GtkSalGraphics::NWPaintGTKCheck( GdkDrawable* gdkDrawable,
                                       ControlType, ControlPart,
                                       const Rectangle& rControlRectangle,
-                                      const clipList& rClipList,
+                                      const std::list< Rectangle >& rClipList,
                                       ControlState nState,
                                       const ImplControlValue& aValue,
                                       const OUString& )
@@ -1920,7 +1920,7 @@ bool GtkSalGraphics::NWPaintGTKCheck( GdkDrawable* gdkDrawable,
     NWSetWidgetState( gWidgetData[m_nXScreen].gCheckWidget, nState, stateType );
     GTK_TOGGLE_BUTTON(gWidgetData[m_nXScreen].gCheckWidget)->active = isChecked;
 
-    for( clipList::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
+    for( std::list< Rectangle >::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
     {
         clipRect.x = it->Left();
         clipRect.y = it->Top();
@@ -1949,7 +1949,7 @@ static void NWCalcArrowRect( const Rectangle& rButton, Rectangle& rArrow )
 
 bool GtkSalGraphics::NWPaintGTKScrollbar( ControlType, ControlPart nPart,
                                           const Rectangle& rControlRectangle,
-                                          const clipList&,
+                                          const std::list< Rectangle >&,
                                           ControlState nState,
                                           const ImplControlValue& aValue,
                                           const OUString& )
@@ -2351,7 +2351,7 @@ static Rectangle NWGetScrollButtonRect(    SalX11Screen nScreen, ControlPart nPa
 bool GtkSalGraphics::NWPaintGTKEditBox( GdkDrawable* gdkDrawable,
                                         ControlType nType, ControlPart nPart,
                                         const Rectangle& rControlRectangle,
-                                        const clipList& rClipList,
+                                        const std::list< Rectangle >& rClipList,
                                         ControlState nState,
                                         const ImplControlValue& aValue,
                                         const OUString& rCaption )
@@ -2363,7 +2363,7 @@ bool GtkSalGraphics::NWPaintGTKEditBox( GdkDrawable* gdkDrawable,
     // plus its actual draw rect excluding adornment
     pixmapRect = NWGetEditBoxPixmapRect( m_nXScreen, nType, nPart, rControlRectangle,
                                          nState, aValue, rCaption );
-    for( clipList::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
+    for( std::list< Rectangle >::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
     {
         clipRect.x = it->Left();
         clipRect.y = it->Top();
@@ -2483,7 +2483,7 @@ static void NWPaintOneEditBox(    SalX11Screen nScreen,
 
 bool GtkSalGraphics::NWPaintGTKSpinBox(ControlType nType, ControlPart nPart,
                                        const Rectangle& rControlRectangle,
-                                       const clipList&,
+                                       const std::list< Rectangle >&,
                                        ControlState nState,
                                        const ImplControlValue& aValue,
                                        const OUString& rCaption,
@@ -2657,7 +2657,7 @@ static void NWPaintOneSpinButton( SalX11Screen nScreen,
 bool GtkSalGraphics::NWPaintGTKComboBox( GdkDrawable* gdkDrawable,
                                          ControlType nType, ControlPart nPart,
                                          const Rectangle& rControlRectangle,
-                                         const clipList& rClipList,
+                                         const std::list< Rectangle >& rClipList,
                                          ControlState nState,
                                          const ImplControlValue& aValue,
                                          const OUString& rCaption )
@@ -2700,7 +2700,7 @@ bool GtkSalGraphics::NWPaintGTKComboBox( GdkDrawable* gdkDrawable,
     arrowRect.SetPos( Point( buttonRect.Left() + (gint)((buttonRect.GetWidth() - arrowRect.GetWidth()) / 2),
                              buttonRect.Top() + (gint)((buttonRect.GetHeight() - arrowRect.GetHeight()) / 2) ) );
 
-    for( clipList::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
+    for( std::list< Rectangle >::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
     {
         clipRect.x = it->Left();
         clipRect.y = it->Top();
@@ -2790,7 +2790,7 @@ static Rectangle NWGetComboBoxButtonRect( SalX11Screen nScreen,
 
 bool GtkSalGraphics::NWPaintGTKTabItem( ControlType nType, ControlPart,
                                         const Rectangle& rControlRectangle,
-                                        const clipList&,
+                                        const std::list< Rectangle >&,
                                         ControlState nState,
                                         const ImplControlValue& aValue,
                                         const OUString& )
@@ -2943,7 +2943,7 @@ bool GtkSalGraphics::NWPaintGTKTabItem( ControlType nType, ControlPart,
 bool GtkSalGraphics::NWPaintGTKListBox( GdkDrawable* gdkDrawable,
                                         ControlType nType, ControlPart nPart,
                                         const Rectangle& rControlRectangle,
-                                        const clipList& rClipList,
+                                        const std::list< Rectangle >& rClipList,
                                         ControlState nState,
                                         const ImplControlValue& aValue,
                                         const OUString& rCaption )
@@ -2981,7 +2981,7 @@ bool GtkSalGraphics::NWPaintGTKListBox( GdkDrawable* gdkDrawable,
             nullptr);
     }
 
-    for( clipList::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
+    for( std::list< Rectangle >::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
     {
         clipRect.x = it->Left();
         clipRect.y = it->Top();
@@ -3020,7 +3020,7 @@ bool GtkSalGraphics::NWPaintGTKToolbar(
             GdkDrawable* gdkDrawable,
             ControlType, ControlPart nPart,
             const Rectangle& rControlRectangle,
-            const clipList& rClipList,
+            const std::list< Rectangle >& rClipList,
             ControlState nState, const ImplControlValue& aValue,
             const OUString& string)
 {
@@ -3097,7 +3097,7 @@ bool GtkSalGraphics::NWPaintGTKToolbar(
 
     if( nPart != PART_BUTTON )
     {
-        for( clipList::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
+        for( std::list< Rectangle >::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
         {
             clipRect.x = it->Left();
             clipRect.y = it->Top();
@@ -3200,7 +3200,7 @@ bool GtkSalGraphics::NWPaintGTKMenubar(
             GdkDrawable* gdkDrawable,
             ControlType, ControlPart nPart,
             const Rectangle& rControlRectangle,
-            const clipList& rClipList,
+            const std::list< Rectangle >& rClipList,
             ControlState nState, const ImplControlValue&,
             const OUString& )
 {
@@ -3228,7 +3228,7 @@ bool GtkSalGraphics::NWPaintGTKMenubar(
         }
     }
 
-    for( clipList::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
+    for( std::list< Rectangle >::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
     {
         lcl_rectangleToGdkRectangle(*it, clipRect);
 
@@ -3287,7 +3287,7 @@ bool GtkSalGraphics::NWPaintGTKPopupMenu(
             GdkDrawable* gdkDrawable,
             ControlType, ControlPart nPart,
             const Rectangle& rControlRectangle,
-            const clipList& rClipList,
+            const std::list< Rectangle >& rClipList,
             ControlState nState, const ImplControlValue&,
             const OUString& )
 {
@@ -3325,7 +3325,7 @@ bool GtkSalGraphics::NWPaintGTKPopupMenu(
     if ( nState & ControlState::ENABLED )
         GTK_WIDGET_SET_FLAGS( gWidgetData[m_nXScreen].gMenuWidget, GTK_SENSITIVE );
 
-    for( clipList::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
+    for( std::list< Rectangle >::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
     {
         clipRect.x = it->Left();
         clipRect.y = it->Top();
@@ -3452,7 +3452,7 @@ bool GtkSalGraphics::NWPaintGTKTooltip(
             GdkDrawable* gdkDrawable,
             ControlType, ControlPart,
             const Rectangle& rControlRectangle,
-            const clipList& rClipList,
+            const std::list< Rectangle >& rClipList,
             ControlState, const ImplControlValue&,
             const OUString& )
 {
@@ -3466,7 +3466,7 @@ bool GtkSalGraphics::NWPaintGTKTooltip(
     w = rControlRectangle.GetWidth();
     h = rControlRectangle.GetHeight();
 
-    for( clipList::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
+    for( std::list< Rectangle >::const_iterator it = rClipList.begin(); it != rClipList.end(); ++it )
     {
         clipRect.x = it->Left();
         clipRect.y = it->Top();
@@ -3490,7 +3490,7 @@ bool GtkSalGraphics::NWPaintGTKListNode(
             GdkDrawable*,
             ControlType, ControlPart,
             const Rectangle& rControlRectangle,
-            const clipList&,
+            const std::list< Rectangle >&,
             ControlState nState, const ImplControlValue& rValue,
             const OUString& )
 {
@@ -3540,7 +3540,7 @@ bool GtkSalGraphics::NWPaintGTKProgress(
             GdkDrawable*,
             ControlType, ControlPart,
             const Rectangle& rControlRectangle,
-            const clipList&,
+            const std::list< Rectangle >&,
             ControlState, const ImplControlValue& rValue,
             const OUString& )
 {
@@ -3605,7 +3605,7 @@ bool GtkSalGraphics::NWPaintGTKSlider(
             GdkDrawable*,
             ControlType, ControlPart nPart,
             const Rectangle& rControlRectangle,
-            const clipList&,
+            const std::list< Rectangle >&,
             ControlState nState, const ImplControlValue& rValue,
             const OUString& )
 {
diff --git a/vcl/win/gdi/gdiimpl.cxx b/vcl/win/gdi/gdiimpl.cxx
index f9deaf7..5af458b 100644
--- a/vcl/win/gdi/gdiimpl.cxx
+++ b/vcl/win/gdi/gdiimpl.cxx
@@ -2194,7 +2194,7 @@ bool WinSalGraphicsImpl::tryDrawBitmapGdiPlus(const SalTwoRect& rTR, const SalBi
         assert(dynamic_cast<const WinSalBitmap*>(&rSrcBitmap));
 
         const WinSalBitmap& rSalBitmap = static_cast< const WinSalBitmap& >(rSrcBitmap);
-        GdiPlusBmpPtr aARGB(rSalBitmap.ImplGetGdiPlusBitmap());
+        std::shared_ptr< Gdiplus::Bitmap > aARGB(rSalBitmap.ImplGetGdiPlusBitmap());
 
         if(aARGB.get())
         {
@@ -2247,7 +2247,7 @@ bool WinSalGraphicsImpl::drawAlphaBitmap(
 
         const WinSalBitmap& rSalBitmap = static_cast< const WinSalBitmap& >(rSrcBitmap);
         const WinSalBitmap& rSalAlpha = static_cast< const WinSalBitmap& >(rAlphaBmp);
-        GdiPlusBmpPtr aARGB(rSalBitmap.ImplGetGdiPlusBitmap(&rSalAlpha));
+        std::shared_ptr< Gdiplus::Bitmap > aARGB(rSalBitmap.ImplGetGdiPlusBitmap(&rSalAlpha));
 
         if(aARGB.get())
         {
@@ -2284,7 +2284,7 @@ bool WinSalGraphicsImpl::drawTransformedBitmap(
 
     const WinSalBitmap& rSalBitmap = static_cast< const WinSalBitmap& >(rSourceBitmap);
     const WinSalBitmap* pSalAlpha = static_cast< const WinSalBitmap* >(pAlphaBitmap);
-    GdiPlusBmpPtr aARGB(rSalBitmap.ImplGetGdiPlusBitmap(pSalAlpha));
+    std::shared_ptr< Gdiplus::Bitmap > aARGB(rSalBitmap.ImplGetGdiPlusBitmap(pSalAlpha));
 
     if(aARGB.get())
     {
diff --git a/vcl/win/gdi/salbmp.cxx b/vcl/win/gdi/salbmp.cxx
index 9b18753..b51ec6f 100644
--- a/vcl/win/gdi/salbmp.cxx
+++ b/vcl/win/gdi/salbmp.cxx
@@ -214,7 +214,7 @@ void WinSalBitmap::Destroy()
     mnBitCount = 0;
 }
 
-GdiPlusBmpPtr WinSalBitmap::ImplGetGdiPlusBitmap(const WinSalBitmap* pAlphaSource) const
+std::shared_ptr< Gdiplus::Bitmap > WinSalBitmap::ImplGetGdiPlusBitmap(const WinSalBitmap* pAlphaSource) const
 {
     WinSalBitmap* pThat = const_cast< WinSalBitmap* >(this);
 
diff --git a/vcl/win/gdi/salfont.cxx b/vcl/win/gdi/salfont.cxx
index ba92247..b19e919 100644
--- a/vcl/win/gdi/salfont.cxx
+++ b/vcl/win/gdi/salfont.cxx
@@ -2505,7 +2505,7 @@ const Ucs2SIntMap* WinSalGraphics::GetFontEncodingVector( const PhysicalFontFace
 
 void WinSalGraphics::GetGlyphWidths( const PhysicalFontFace* pFont,
                                      bool bVertical,
-                                     Int32Vector& rWidths,
+                                     std::vector< sal_Int32 >& rWidths,
                                      Ucs2UIntMap& rUnicodeEnc )
 {
     // create matching FontSelectPattern


More information about the Libreoffice-commits mailing list
diff --git a/vcl/osx/salinst.cxx b/vcl/osx/salinst.cxx
index 31b1542..54c3ba9 100644
--- a/vcl/osx/salinst.cxx
+++ b/vcl/osx/salinst.cxx
@@ -109,8 +109,8 @@ void AquaSalInstance::delayedSettingsChanged( bool bInvalidate )
     pIdle->Start();
 }
 
-// the AppEventList must be available before any SalData/SalInst/etc. objects are ready
-AquaSalInstance::AppEventList AquaSalInstance::aAppEventList;
+// the std::list<const ApplicationEvent*> must be available before any SalData/SalInst/etc. objects are ready
+std::list<const ApplicationEvent*> AquaSalInstance::aAppEventList;
 
 NSMenu* AquaSalInstance::GetDynamicDockMenu()
 {